import { Bainy4Model, Bainy4PageParams, Bainy4PageResult } from './model/Bainy4Model';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/bi/bainy4/page',
  List = '/bi/bainy4/list',
  Info = '/bi/bainy4/info',
  Bainy4 = '/bi/bainy4',
  
  
}

/**
 * @description: 查询Bainy4分页列表
 */
export async function getBainy4Page(params: Bainy4PageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bainy4PageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取Bainy4信息
 */
export async function getBainy4(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bainy4Model>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增Bainy4
 */
export async function addBainy4(bainy4: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.Bainy4,
      params: bainy4,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新Bainy4
 */
export async function updateBainy4(bainy4: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.Bainy4,
      params: bainy4,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除Bainy4（批量删除）
 */
export async function deleteBainy4(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.Bainy4,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}