import { Bainyi2Model, Bainyi2PageParams, Bainyi2PageResult } from './model/Bainyi2Model';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/bi/bainyi2/page',
  List = '/bi/bainyi2/list',
  Info = '/bi/bainyi2/info',
  Bainyi2 = '/bi/bainyi2',
  
  
}

/**
 * @description: 查询Bainyi2分页列表
 */
export async function getBainyi2Page(params: Bainyi2PageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bainyi2PageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取Bainyi2信息
 */
export async function getBainyi2(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bainyi2Model>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增Bainyi2
 */
export async function addBainyi2(bainyi2: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.Bainyi2,
      params: bainyi2,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新Bainyi2
 */
export async function updateBainyi2(bainyi2: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.Bainyi2,
      params: bainyi2,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除Bainyi2（批量删除）
 */
export async function deleteBainyi2(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.Bainyi2,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}