import { TestBianyiModel, TestBianyiPageParams, TestBianyiPageResult } from './model/Bainyi5Model';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/bi/bainyi5/page',
  List = '/bi/bainyi5/list',
  Info = '/bi/bainyi5/info',
  TestBianyi = '/bi/bainyi5',
  
  
}

/**
 * @description: 查询TestBianyi分页列表
 */
export async function getTestBianyiPage(params: TestBianyiPageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<TestBianyiPageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取TestBianyi信息
 */
export async function getTestBianyi(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<TestBianyiModel>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增TestBianyi
 */
export async function addTestBianyi(testBianyi: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.TestBianyi,
      params: testBianyi,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新TestBianyi
 */
export async function updateTestBianyi(testBianyi: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.TestBianyi,
      params: testBianyi,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除TestBianyi（批量删除）
 */
export async function deleteTestBianyi(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.TestBianyi,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}