import { Bianyi3Model, Bianyi3PageParams, Bianyi3PageResult } from './model/Bianyi3Model';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/bi/bianyi3/page',
  List = '/bi/bianyi3/list',
  Info = '/bi/bianyi3/info',
  Bianyi3 = '/bi/bianyi3',
  
  
}

/**
 * @description: 查询Bianyi3分页列表
 */
export async function getBianyi3Page(params: Bianyi3PageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bianyi3PageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取Bianyi3信息
 */
export async function getBianyi3(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<Bianyi3Model>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增Bianyi3
 */
export async function addBianyi3(bianyi3: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.Bianyi3,
      params: bianyi3,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新Bianyi3
 */
export async function updateBianyi3(bianyi3: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.Bianyi3,
      params: bianyi3,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除Bianyi3（批量删除）
 */
export async function deleteBianyi3(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.Bianyi3,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}