import { XjrUserPageParams, XjrUserPageResult } from './model/TeacherbaseManagerModel';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/teacher/teacherbasemanager/page',
  List = '/teacher/teacherbasemanager/list',
  Info = '/teacher/teacherbasemanager/info',
  XjrUser = '/teacher/teacherbasemanager',
}

/**
 * @description: 查询XjrUser分页列表
 */
export async function getXjrUserPage(params: XjrUserPageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<XjrUserPageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取XjrUser信息
 */
export async function getXjrUser(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增XjrUser
 */
export async function addXjrUser(xjrUser: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.XjrUser,
      params: xjrUser,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新XjrUser
 */
export async function updateXjrUser(xjrUser: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.XjrUser,
      params: xjrUser,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除XjrUser（批量删除）
 */
export async function deleteXjrUser(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.XjrUser,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
