import {
  BaseTeacherModel,
  BaseTeacherPageParams,
  BaseTeacherPageResult,
} from './model/TeacherManagerModel';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/dev/teachermanager/page',
  List = '/dev/teachermanager/list',
  Info = '/dev/teachermanager/info',
  BaseTeacher = '/dev/teachermanager',
}

/**
 * @description: 查询BaseTeacher分页列表
 */
export async function getBaseTeacherPage(
  params: BaseTeacherPageParams,
  mode: ErrorMessageMode = 'modal',
) {
  return defHttp.get<BaseTeacherPageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取BaseTeacher信息
 */
export async function getBaseTeacher(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<BaseTeacherModel>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增BaseTeacher
 */
export async function addBaseTeacher(baseTeacher: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.BaseTeacher,
      params: baseTeacher,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新BaseTeacher
 */
export async function updateBaseTeacher(baseTeacher: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.BaseTeacher,
      params: baseTeacher,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除BaseTeacher（批量删除）
 */
export async function deleteBaseTeacher(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.BaseTeacher,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
