import { TeacherManagerModel, TeacherManagerPageParams, TeacherManagerPageResult } from './model/TeacherManagerModel';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  Page = '/jinayi/teachermanager/page',
  List = '/jinayi/teachermanager/list',
  Info = '/jinayi/teachermanager/info',
  TeacherManager = '/jinayi/teachermanager',
  
  
}

/**
 * @description: 查询TeacherManager分页列表
 */
export async function getTeacherManagerPage(params: TeacherManagerPageParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<TeacherManagerPageResult>(
    {
      url: Api.Page,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 获取TeacherManager信息
 */
export async function getTeacherManager(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<TeacherManagerModel>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 新增TeacherManager
 */
export async function addTeacherManager(teacherManager: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.TeacherManager,
      params: teacherManager,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 更新TeacherManager
 */
export async function updateTeacherManager(teacherManager: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.TeacherManager,
      params: teacherManager,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: 删除TeacherManager（批量删除）
 */
export async function deleteTeacherManager(ids: string[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.TeacherManager,
      data: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}