import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode, UploadFileParams } from '/#/axios';
enum API {
  GETCODE = '/system/code-rule/generate',
  BASEFACE = '/personnel/facemanager/add',
  BASE = '/personnel/facemanager',
  EDITFACE = '/personnel/facemanager/update',
  PAGE = '/personnel/facemanager/page',
  INFO = '/personnel/facemanager/info',
  DELETE = '/personnel/facemanager/delete',
}
export async function getFacePage(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<any>(
    {
      url: API.PAGE,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function getFaceInfo(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<any>(
    {
      url: API.INFO,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function addFace(face: UploadFileParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: API.BASEFACE,
      params: face,
      headers: { 'Content-Type': 'multipart/form-data' },
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function updateFace(face: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: API.EDITFACE,
      params: face,
      headers: { 'Content-Type': 'multipart/form-data' },
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function deleteFace(ids: number[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: API.BASE,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function getCode(encode: string, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<any>(
    {
      url: API.GETCODE,
      params: { encode: encode },
    },
    {
      errorMessageMode: mode,
    },
  );
}
