import { addCarModel } from './model/baseModel';
import { defHttp } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';

enum Api {
  BASE = '/personnel/carmanager',
  Info = '/personnel/carmanager/info',
  PAGE = '/personnel/carmanager/page',
}
export async function getCarPage(params: addCarModel, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<addCarModel>(
    {
      url: Api.PAGE,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function getCarInfo(id: String, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<addCarModel>(
    {
      url: Api.Info,
      params: { id },
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function addCar(car: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<boolean>(
    {
      url: Api.BASE,
      params: car,
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function updateCar(car: Recordable, mode: ErrorMessageMode = 'modal') {
  return defHttp.put<boolean>(
    {
      url: Api.BASE,
      params: car,
    },
    {
      errorMessageMode: mode,
    },
  );
}
export async function deleteCar(ids: number[], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete<boolean>(
    {
      url: Api.BASE,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
