import { defHttp } from '/@/utils/http/axios';

import { ErrorMessageMode } from '/#/axios';
import {
  getMenuListResultModel,
  GetUserInfoModel,
  LoginParams,
  LoginResultModel,
  newConfigModel,
  newsList,
  PermissionResultModel,
} from './model';

enum Api {
  Login = '/system/login',
  Logout = '/system/logout',
  GetUserInfo = '/organization/user/current/info',
  GetPermCode = '/system/authorize/permissions',
  GetUserMenuTree = '/system/menu/tree',
  TestRetry = '/testRetry',
  OA = '/oa/message/list',
  OANews = '/oa/news/box',
  NRWS = '/oa/news',
  Read = '/oa/news/read',
  workReadAll = '/oa/message/read-all-message',
  schemaReadAll = '/oa/message/read-all-schedule-message',
  Single = '/oa/message/read-message',
  Img = '/system/imgcaptcha',
  newInfo = '/oa/news/info',
  Reply = '/oa/news/reply',
  relation = '/oa/news/count-relation',
  relationPage = '/oa/news/page-relation',
  putPrison = '/oa/news/update-relation',
  getPrisonConfig = '/oa/news/page-relation-config',
  ADMINPAGE = '/oa/news',
}

/**
 * @description: user login api
 */
export function loginApi(params: LoginParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<LoginResultModel>(
    {
      url: Api.Login,
      params,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * @description: getUserInfo
 */
export function getUserInfo() {
  return defHttp.get<GetUserInfoModel>({ url: Api.GetUserInfo }, { errorMessageMode: 'none' });
}

export function getPermCode() {
  return defHttp.get<PermissionResultModel>({ url: Api.GetPermCode });
}

export function doLogout() {
  return defHttp.post({ url: Api.Logout });
}

export function testRetry() {
  return defHttp.get(
    { url: Api.TestRetry },
    {
      retryRequest: {
        isOpenRetry: true,
        count: 5,
        waitTime: 1000,
      },
    },
  );
}

/**
 * @description: Get user menu based on id
 */

export const getMenuList = (params) => {
  return defHttp.get<getMenuListResultModel>({ url: Api.GetUserMenuTree, params: params });
};

export function getOaMessage() {
  return defHttp.get({ url: Api.OA });
}

export function getOaNews(type, mode: ErrorMessageMode = 'modal') {
  return defHttp.get<newsList>(
    { url: Api.OANews, params: type },
    {
      errorMessageMode: mode,
    },
  );
}
export function setOaRead(id, mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.Read, params: id },
    {
      errorMessageMode: mode,
    },
  );
}

export function setWorkReadAll(mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.workReadAll },
    {
      errorMessageMode: mode,
    },
  );
}

export function setSchemaReadAll(mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.schemaReadAll },
    {
      errorMessageMode: mode,
    },
  );
}

export function setSingleRead(id, mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.Single, params: { id } },
    {
      errorMessageMode: mode,
    },
  );
}

// 获取验证码
export function getImg() {
  return defHttp.get({ url: Api.Img });
}
export function addNews(params: newConfigModel, mode: ErrorMessageMode = 'modal') {
  return defHttp.post(
    { url: Api.NRWS, params: params },
    {
      errorMessageMode: mode,
    },
  );
}

export function editNews(params: newConfigModel, mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.NRWS, params: params },
    {
      errorMessageMode: mode,
    },
  );
}
export function getNewsInfo(id: string, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    { url: Api.newInfo, params: { id } },
    {
      errorMessageMode: mode,
    },
  );
}

// 回复消息
export function replyNews(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.Reply, params: params },
    {
      errorMessageMode: mode,
    },
  );
}
// 获取阅读统计
export function getRelation(id: string, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    { url: Api.relation, params: { id: id } },
    {
      errorMessageMode: mode,
    },
  );
}
// 获取阅读统计分页
export function getRelationPage(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    { url: Api.relationPage, params },
    {
      errorMessageMode: mode,
    },
  );
}

// 删除新闻公告
export function delNews(ids: [], mode: ErrorMessageMode = 'modal') {
  return defHttp.delete(
    { url: Api.NRWS, data: ids },
    {
      errorMessageMode: mode,
    },
  );
}

// 新增阅读权限
export function putPrison(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.put(
    { url: Api.putPrison, params },
    {
      errorMessageMode: mode,
    },
  );
}
// 查看阅读权限
export function getPrisonConfig(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    { url: Api.getPrisonConfig, params },
    {
      errorMessageMode: mode,
    },
  );
}
// 获取管理端新闻公告列表
export function getAdminNews(params: any, mode: ErrorMessageMode = 'modal') {
  return defHttp.get(
    { url: Api.ADMINPAGE, params },
    {
      errorMessageMode: mode,
    },
  );
}
