import { RouteMeta } from 'vue-router';
import { DesktopData } from '/@/model/desktop/designer';
import { BasicFetchResult } from '/@/api/model/baseModel';
/**
 * @description: Login interface parameters
 */
export interface LoginParams {
  userName: string;
  password: string;
  key: string;
  code: string;
}

export interface RoleInfo {
  name: string;
  id: string;
  code: string;
}

export type DepartmentInfo = RoleInfo;

export type PostInfo = RoleInfo;
/**
 * @description: Login interface return value
 */
export interface LoginResultModel {
  token: string;
  redirectUri: string | null;
}

/**
 * @description: Permissions interface retrun value
 */
export interface MenuAuthModel {
  menuId: string;
  buttonAuthCode: string[];
  columnAuthCode: string[];
  formAuthCode: string[];
}

/**
 * @description: Permissions interface retrun value
 */
export interface PermissionResultModel {
  postId: string;
  departmentId: string;
  postName: string;
  departmentName: string;
  menuAuthList: MenuAuthModel[];
  desktopSchema: DesktopData;
}

/**
 * @description: Get user information return value
 */
export interface GetUserInfoModel {
  // 用户id
  id: string;
  // 真实名字
  name: string;
  // 编码
  code: string;
  // 手机
  mobile: string;
  //角色
  roles: RoleInfo[];
  // 用户名
  userName: string;
  // 头像
  avatar: string;
  //部门id
  departmentId: string | number;
  //所有部门
  departments: DepartmentInfo[];
  //所有部门
  posts: PostInfo[];
  //备注
  remark: string;
  //邮箱
  email: string;
  //地址
  address: string;
  //首页地址
  homePath: string;
}

export interface RouteItem {
  path: string;
  component: any;
  meta: RouteMeta;
  name?: string;
  alias?: string | string[];
  redirect?: string;
  caseSensitive?: boolean;
  children?: RouteItem[];
}

/**
 * @description: Get menu return value
 */
export type getMenuListResultModel = RouteItem[];

export interface newConfigModel {
  authorName: string;
  briefHead: string;
  category: string;
  categoryId: string;
  compileName: string;
  fullHead: string;
  fullHeadColor: string;
  keyword: string;
  newsContent: string;
  releaseTime: string;
  remark: string;
  sourceAddress: string;
  sourceName: string;
  tagWord: string;
  typeId: string;
}

export interface newsModel {
  authorName: string;
  briefHead: string;
  category: string;
  categoryId: number;
  classId: number;
  compileName: string;
  emergent: number;
  enabledMark: number;
  fullHead: string;
  fullHeadColor: string;
  id: number;
  keyword: string;
  level: number;
  newsContent: string;
  openForward: number;
  openReply: number;
  openViewOther: number;
  readId: number;
  releaseTime: string;
  remark: string;
  sendDeptId: number;
  sendEndDate: string;
  sendStartDate: string;
  sourceAddress: string;
  sourceName: string;
  tagWord: string;
  typeId: number;
}

export type newsList = BasicFetchResult<newsModel>;
