import { encrypt, decrypt } from 'crypto-js/aes';
import { parse } from 'crypto-js/enc-utf8';
import pkcs7 from 'crypto-js/pad-pkcs7';
import ECB from 'crypto-js/mode-ecb';
import md5 from 'crypto-js/md5';
import UTF8 from 'crypto-js/enc-utf8';
import Base64 from 'crypto-js/enc-base64';
import JSEncrypt from 'jsencrypt';
export interface EncryptionParams {
  key: string;
  iv: string;
}

export class AesEncryption {
  private key;
  private iv;

  constructor(opt: Partial<EncryptionParams> = {}) {
    const { key, iv } = opt;
    if (key) {
      this.key = parse(key);
    }
    if (iv) {
      this.iv = parse(iv);
    }
  }

  get getOptions() {
    return {
      mode: ECB,
      padding: pkcs7,
      iv: this.iv,
    };
  }

  encryptByAES(cipherText: string) {
    return encrypt(cipherText, this.key, this.getOptions).toString();
  }

  decryptByAES(cipherText: string) {
    return decrypt(cipherText, this.key, this.getOptions).toString(UTF8);
  }
}

export function encryptByBase64(cipherText: string) {
  return UTF8.parse(cipherText).toString(Base64);
}

export function decodeByBase64(cipherText: string) {
  return Base64.parse(cipherText).toString(UTF8);
}

export function encryptByMd5(password: string) {
  return md5(password).toString();
}

//Rsa加密
export function encryptRsa(password: string) {
  const pubKey =
    'MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCEiAbUjwK6wULhza0f6SoKzL/2ZKVmlX9OE4hB2W0phGVj14ivvhy3m0vUgWBTm/WQhQIsvtyaElq+apwVLpNvStGm8n4TT/MvPww2v9d5T1Kiu/pqxOxTifSx63KSD1lYCH9yM0RyDMQfSjps/FC7lS7AcoDfRZQg3ohhbP5qCwIDAQAB';
  const encryptStr = new JSEncrypt();
  encryptStr.setPublicKey(pubKey);
  return encryptStr.encrypt(password).toString();
}
