import { BasicColumn, FormSchema } from '/@/components/Table';
import { getSchemaPage } from '/@/services/apis/WorkflowSchemaController';
import { getDataOption } from '/@/api/system/dic';
export const type = {
  0: '菜单',
  1: '目录',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
  },
  {
    title: '图标前缀',
    dataIndex: 'prefix',
  },
  {
    title: '图标',
    dataIndex: 'icon',
  },
  {
    title: '模板ID',
    dataIndex: 'schemaId',
  },
  {
    title: '排序',
    dataIndex: 'sortCode',
  },
  {
    title: '类型',
    dataIndex: 'type',
    customRender: ({ text }) => {
      return type[text];
    },
  },
  {
    title: '功能地址',
    dataIndex: 'url',
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const formSchema: FormSchema[] = [
  {
    label: '配置名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标前缀',
    field: 'prefix',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标',
    field: 'icon',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标颜色',
    field: 'color',
    component: 'ColorPicker',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '排序',
    field: 'sortCode',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '模板Id',
    field: 'schemaId',
    component: 'ApiSelect',
    componentProps: {
      api: async () => {
        return (await getSchemaPage({ size: 100, limit: 1 })).list;
      },
      labelField: 'name',
      valueField: 'id',
      multiple: false,
      filterable: true,
    },
    colProps: { span: 24 },
  },
  {
    label: '功能分类',
    field: 'type',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'APPFUNC' });
      },
      multiple: false,
      filterable: true,
    },
    colProps: { span: 24 },
  },
  {
    label: '功能地址',
    field: 'url',
    component: 'Input',
    colProps: { span: 24 },
  },
];
