import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
import { FormSchema } from '/@/components/Form/index';

export const formStudentSchema: FormSchema[] = [
  {
    label: '年级',
    field: 'gradeId',
    component: 'ApiSelect',
    // required: true,
    componentProps: ({ formModel }) => {
      return {
        api: requestMagicApi,
        params: { url: 'baseData/grade/option' },
        onChange: (_) => {
          formModel.classId = undefined;
        },
      };
    },
    colProps: { span: 12 },
  },
  {
    label: '行政班',
    field: 'classId',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: { url: `educational/class/gradeid?grade_id=${formModel.gradeId}` },
      };
    },
    colProps: { span: 12 },
  },
  {
    label: '性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 12 },
  },
  {
    field: 'studentName',
    label: '姓名',
    component: 'Input',
    colProps: { span: 12 },
  },
];

const DataList = await requestMagicApi({ url: 'baseData/dormitory/info' } as any);

export const formRoomSchema: FormSchema[] = [
  {
    field: 'isEmptyRoom',
    label: '空寝室',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '是', value: '1' },
        { label: '否', value: '0' },
      ],
    },
  },
  {
    field: 'buildId',
    label: '楼栋',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              getPopupContainer: () => document.body,
              options,
            },
          });
        },
      };
    },
  },
  {
    field: 'floorNumber',
    label: '楼层',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'gender',
    label: '入住性别',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
  },
  {
    field: 'roomName',
    label: '寝室号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'isMax',
    label: '混合寝室',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '是', value: '1' },
        { label: '否', value: '0' },
      ],
    },
  },
  {
    field: 'classId',
    label: '班级',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: 'educational/class/option' },
    },
    colProps: { span: 8 },
  },
];
