import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';
export const type = {
  0: '菜单',
  1: '目录',
};

const DataList = await requestMagicApi({ url: 'baseData/dormitory/info' } as any);
export const TableColumns: BasicColumn[] = [
  {
    title: '楼栋名称',
    dataIndex: 'bulidName',
  },
  {
    title: '楼层',
    dataIndex: 'floorNumber',
    customRender: ({ text }) => {
      return text ? `${text}层` : '/';
    },
  },
  {
    title: '寝室',
    dataIndex: 'roomName',
  },
  {
    title: '入住身份',
    dataIndex: 'checkInStatusCn',
  },
  {
    title: '入住性别',
    dataIndex: 'genderCn',
  },
  {
    title: '床位数',
    dataIndex: 'bedCount',
  },
  {
    title: '寝室长',
    dataIndex: 'studentAppointNames',
  },
  {
    title: '宿管',
    dataIndex: 'teacherAppointNames',
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    label: 'id',
    field: 'id',
    component: 'Input',
    show: false,
  },
  {
    label: '楼栋名称',
    field: 'officeBuildId',
    component: 'Select',
    dynamicDisabled: (formSchema) => {
      return !!formSchema.model.id;
    },
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
                mode: 'multiple',
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              getPopupContainer: () => document.body,
              options,
              mode: 'multiple',
            },
          });
        },
      };
    },
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '楼层',
    field: 'floorNumber',
    component: 'Select',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      getPopupContainer: () => document.body,
    },
    dynamicDisabled: (formSchema) => {
      return !!formSchema.model.id;
    },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    required: true,
    dynamicDisabled: (formSchema) => {
      return !!formSchema.model.id;
    },
    colProps: { span: 12 },
  },
  {
    label: '入住身份',
    field: 'checkInStatus',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'check_in_status' },
    },
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '每层房间数',
    field: 'floorRoomsCount',
    component: 'InputNumber',
    required: true,
    ifShow: (formSchema) => {
      return !formSchema.model.id;
    },
    colProps: { span: 12 },
  },
  {
    label: '床位数',
    field: 'bedCount',
    component: 'InputNumber',
    required: true,
    colProps: { span: 12 },
    ifShow: (formSchema) => {
      return !formSchema.model.id;
    },
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    label: '楼栋名称',
    field: 'officeBuildId',
    component: 'Select',
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              getPopupContainer: () => document.body,
              options,
            },
          });
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '楼层',
    field: 'floorNumber',
    component: 'Select',
    colProps: { span: 6 },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 6 },
  },
  {
    label: '入住身份',
    field: 'checkInStatus',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'check_in_status' },
    },
    colProps: { span: 6 },
  },
];
