import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/TableForm';
const DataList = await requestMagicApi({ url: 'baseData/dormitory/info' } as any);
export const listColumns: BasicColumn[] = [
  {
    title: '年级',
    dataIndex: 'gradeName',
    width: 120,
  },
  {
    title: '专业部',
    dataIndex: 'orgName',
  },
  {
    title: '行政班',
    dataIndex: 'className',
  },
  {
    title: '需住宿人数',
    dataIndex: 'needCount',
  },
  {
    title: '已分配床位数',
    dataIndex: 'distributeCount',
  },
  {
    title: '还需分配床位数',
    dataIndex: 'unassignedNumber',
    customRender: ({ record }) => {
      return record.needCount - record.distributeCount;
    },
  },
];
export const listFormSchema: FormSchema[] = [
  {
    label: '年级',
    field: 'gradeId',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: requestMagicApi,
        params: { url: 'baseData/grade/option' },
        onChange: () => {
          formModel.classId = undefined;
        },
      };
    },
    colProps: { span: 8 },
  },
  {
    label: '行政班',
    field: 'classId',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: { url: `educational/class/gradeid?grade_id=${formModel.gradeId}` },
      };
    },
    colProps: { span: 8 },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 8 },
  },
];

export const badRoomListColumns: BasicColumn[] = [
  {
    title: '楼栋',
    dataIndex: 'buildName',
  },
  {
    title: '楼层',
    dataIndex: 'floorNumber',
    customRender: ({ text }) => {
      return `${text}层`;
    },
  },
  {
    title: '寝室号',
    dataIndex: 'roomName',
  },
  {
    title: '入住性别',
    dataIndex: 'genderCn',
  },
  {
    title: '入住身份',
    dataIndex: 'checkInStatusCn',
  },
  {
    title: '入住班级',
    dataIndex: 'intoClass',
  },
  {
    title: '床位数',
    dataIndex: 'bedCount',
  },
  {
    title: '已入住人数',
    dataIndex: 'intoCount',
  },
  {
    title: '空床位',
    dataIndex: 'emptyBedCount',
    customRender: ({ record }) => {
      return record.bedCount - record.intoCount;
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '楼栋名称',
    field: 'officeBuildId',
    component: 'Select',
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              options,
              getPopupContainer: () => document.body,
            },
          });
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '楼层',
    field: 'floorNumber',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
    },
    colProps: { span: 6 },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 6 },
  },
  {
    label: '寝室号',
    field: 'roomName',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '入住班级',
    field: 'classId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'educational/class/option' },
    },
    colProps: { span: 6 },
  },
];
