import { BasicColumn, FormSchema } from '/@/components/Table';
import { getSchemaPage } from '/@/services/apis/WorkflowSchemaController';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';
export const type = {
  0: '菜单',
  1: '目录',
};
const DataList = await requestMagicApi({ url: 'baseData/dormitory/info' } as any);
export const TableColumns: BasicColumn[] = [
  {
    title: '楼栋名称',
    dataIndex: 'buildName',
    width: 100,
    align: 'left',
  },
  {
    title: '楼层',
    dataIndex: 'floorNumber',
    width: 60,
    align: 'left',
    customRender: ({ text }) => {
      return `${text}层`;
    },
  },
  {
    title: '寝室',
    dataIndex: 'roomName',
    align: 'left',
    width: 80,
  },
  {
    title: '床位号',
    dataIndex: 'bedNumber',
    width: 60,
    align: 'left',
    customRender: ({ text }) => {
      return `${text}号`;
    },
  },
  {
    title: '姓名',
    dataIndex: 'studentName',
    width: 100,
    align: 'left',
  },
  {
    title: '学号',
    dataIndex: 'studentId',
    align: 'left',
  },
  {
    title: '手机号',
    dataIndex: 'mobile',
    width: 120,
    align: 'left',
  },
  {
    title: '入住性别',
    dataIndex: 'genderCn',
    width: 80,
    align: 'left',
  },
  {
    title: '年级',
    dataIndex: 'gradeName',
    width: 100,
    align: 'left',
  },
  {
    title: '所在班级',
    dataIndex: 'className',
    width: 120,
    align: 'left',
  },
  {
    title: '操作',
    dataIndex: 'action',
    ifShow: false,
    slots: { customRender: 'action' },
    fixed: 'right',
    width: 120,
    align: 'left',
  },
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const formSchema: FormSchema[] = [
  {
    label: '配置名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标前缀',
    field: 'prefix',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标',
    field: 'icon',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '图标颜色',
    field: 'color',
    component: 'ColorPicker',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '排序',
    field: 'sortCode',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '模板Id',
    field: 'schemaId',
    component: 'ApiSelect',
    componentProps: {
      api: async () => {
        return (await getSchemaPage({ size: 100, limit: 1 })).list;
      },
      labelField: 'name',
      valueField: 'id',
      multiple: false,
      filterable: true,
    },
    colProps: { span: 24 },
  },
  {
    label: '功能分类',
    field: 'type',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'APPFUNC' });
      },
      multiple: false,
      filterable: true,
    },
    colProps: { span: 24 },
  },
  {
    label: '功能地址',
    field: 'url',
    component: 'Input',
    colProps: { span: 24 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '楼栋名称',
    field: 'officeBuildId',
    component: 'Select',
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              getPopupContainer: () => document.body,
              options,
            },
          });
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '楼层',
    field: 'floorNumber',
    component: 'Select',
    colProps: { span: 6 },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 6 },
  },
  {
    label: '入住身份',
    field: 'identity',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'check_in_status' },
    },
    colProps: { span: 6 },
  },
  {
    label: '年级',
    field: 'gradeId',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/grade/option' },
    },
    colProps: { span: 6 },
  },
  {
    label: '班级',
    field: 'classId',
    component: 'ApiSelect',
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: {
          url: '/educational/class/option',
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    field: 'studentName',
    label: '姓名',
    component: 'Input',
    colProps: { span: 6 },
  },
];
