import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';
export const type = {
  0: '菜单',
  1: '目录',
};
const DataList = await requestMagicApi({ url: 'baseData/dormitory/info' } as any);
export const TableColumns: BasicColumn[] = [
  {
    title: '楼栋名称',
    dataIndex: 'buildName',
  },
  {
    title: '楼层',
    dataIndex: 'floorNumber',
    customRender: ({ text }) => {
      return `${text}层`;
    },
  },
  {
    title: '寝室',
    dataIndex: 'roomName',
  },

  {
    title: '入住性别',
    dataIndex: 'genderCn',
  },
  {
    title: '宿管',
    dataIndex: 'appointUsers',
  },
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const formSchema: FormSchema[] = [
  {
    label: '宿管人员',
    field: 'userIds',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/housemaster/info' },
      mode: 'multiple',
    },
    required: true,
    colProps: { span: 24 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '楼栋名称',
    field: 'officeBuildId',
    component: 'Select',
    componentProps: ({ formActionType, formModel }) => {
      return {
        getPopupContainer: () => document.body,
        options: DataList.map((item) => {
          return { label: item.officeBuildName, value: item.officeBuildId };
        }),
        params: { url: 'baseData/dormitory/info' },
        onChange: (e) => {
          if (!e) {
            formModel.floorNumber = undefined;
            formActionType.updateSchema({
              field: 'floorNumber',
              label: '楼层',
              component: 'Select',
              componentProps: {
                getPopupContainer: () => document.body,
                options: [],
              },
            });
            return false;
          }
          const index = DataList.findIndex((item) => item.officeBuildId === e);
          const options: { label: string; value: number }[] = [];
          for (let index1 = 0; index1 < DataList[index].floorTotal; index1++) {
            options.push({ label: `${index1 + 1}层`, value: index1 + 1 });
          }
          formActionType.updateSchema({
            field: 'floorNumber',
            label: '楼层',
            component: 'Select',
            componentProps: {
              getPopupContainer: () => document.body,
              options,
            },
          });
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '楼层',
    field: 'floorNumber',
    componentProps: {
      getPopupContainer: () => document.body,
    },
    component: 'Select',
    colProps: { span: 6 },
  },
  {
    label: '入住性别',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 6 },
  },
  {
    label: '入住身份',
    field: 'identity',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'check_in_status' },
    },
    colProps: { span: 6 },
  },
  {
    label: '宿管员',
    field: 'userIds',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/housemaster/info' },
    },
    colProps: { span: 6 },
  },
];
