import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';

export const TableColumns: BasicColumn[] = [
  {
    title: '值班时间',
    dataIndex: 'startTime',
    customRender: ({ text, record }) => {
      return `${text}-${record.endTime}`;
    },
    customCell: (_) => {
      if (_.startIndex === 0 || _.startIndex) {
        return { rowSpan: _.sumLength + 1 };
      } else {
        return { rowSpan: 0 };
      }
    },
  },
  {
    title: '值班人员',
    dataIndex: 'userName',
  },
  {
    title: '职务',
    dataIndex: 'postName',
  },
  {
    title: '负责寝室',
    dataIndex: 'roomType',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '留宿人数',
    dataIndex: 'numberPeople',
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right',
  },
];
export const formSchema: FormSchema[] = [
  {
    label: '值周时间',
    field: 'weekTime',
    component: 'RangePicker',
    required: true,
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
        onChange: async (e) => {
          const data = await requestMagicApi({
            url: 'student/stay-overnight/count-info',
            query: { start_date: e[0], end_date: e[1] },
          } as any);
          formModel.maleStudents = data[0].maleStudents;
          formModel.femaleStudents = data[0].femaleStudents;
        },
      };
    },
    colProps: { span: 24 },
  },
  {
    label: '男寝人数',
    field: 'maleStudents',
    component: 'Input',
    dynamicDisabled: true,
    colProps: { span: 12 },
  },
  {
    label: '宿管',
    field: 'maleUserId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'baseData/housemaster/info' },
    },
    required: ({ model }) => {
      return model.maleStudents > 0;
    },
    colProps: { span: 12 },
  },
  {
    label: '女寝人数',
    field: 'femaleStudents',
    component: 'Input',
    dynamicDisabled: true,
    colProps: { span: 12 },
  },
  {
    label: '宿管',
    field: 'femaleUserId',
    component: 'ApiSelect',
    required: ({ model }) => {
      return model.femaleStudents > 0;
    },
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'baseData/housemaster/info' },
    },
    colProps: { span: 12 },
  },
  {
    label: '教官',
    field: 'jiaoguan',
    component: 'Input',
    slot: 'jiaoguan',
    colProps: { span: 12 },
  },
  {
    label: '教官',
    field: 'instructorUserId',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/instructor/info' },
    },
    required: true,
    colProps: { span: 12 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '值周时间',
    field: 'weekTime',
    component: 'RangePicker',
    componentProps: () => {
      return {
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
      };
    },
    colProps: { span: 8 },
  },
  {
    label: '值班人员',
    field: 'userName',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    label: '寝室类型',
    field: 'gender',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 8 },
  },
];
export const editFormSchema: FormSchema[] = [
  {
    label: 'id',
    field: 'id',
    component: 'Input',
    show: false,
  },
  {
    label: '值周时间',
    field: 'weekTime',
    dynamicDisabled: true,
    component: 'RangePicker',
    componentProps: () => {
      return {
        format: 'YYYY-MM-DD',
        valueFormat: 'YYYY-MM-DD',
      };
    },
    colProps: { span: 24 },
  },
  {
    label: '男寝人数',
    field: 'numberPeople',
    component: 'Input',
    dynamicDisabled: true,
    colProps: { span: 12 },
  },
  {
    label: '宿管',
    field: 'userId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'baseData/housemaster/info' },
    },
    required: true,
    colProps: { span: 12 },
  },
];
