import { BasicColumn, FormSchema } from '/@/components/Table';
import { requestMagicApi } from '/@/api/magicApi';
export const type = {
  0: '菜单',
  1: '目录',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '申请人',
    dataIndex: 'applicantUserIdCN',
    align: 'left',
    customRender: ({ record }) => {
      return record.applicantUserIdCN + '(' + record.applicantUserId + ')';
    },
  },
  {
    title: '性别',
    width: 60,
    dataIndex: 'genderName',
  },
  {
    title: '班级',
    width: 100,
    dataIndex: 'className',
  },
  {
    title: '留宿开始时间',
    dataIndex: 'startTime',
    width: 140,
    customRender: ({ text }) => {
      return text ? text.slice(0, 10) : '';
    },
  },
  {
    title: '留宿结束时间',
    dataIndex: 'endTime',
    width: 140,
    customRender: ({ text }) => {
      return text ? text.slice(0, 10) : '';
    },
  },
  {
    title: '时长（天）',
    width: 140,
    dataIndex: 'duration',
    customRender: ({ text }) => {
      return text + '天';
    },
  },
  {
    title: '寝室号',
    align: 'left',
    dataIndex: 'roomBedNumber',
  },
  {
    title: '本人电话',
    width: 120,
    dataIndex: 'mobile',
  },
  {
    title: '监护人电话',
    width: 120,
    dataIndex: 'guardianMobile',
  },
  {},
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const searchFormSchema: FormSchema[] = [
  {
    label: '使用年级',
    field: 'gradeId',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/grade/option' },
    },
    colProps: { span: 6 },
  },
  {
    label: '班级',
    field: 'className',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        valueField: 'label',
        params: { url: `educational/class/gradeid?grade_id=${formModel.gradeId}` },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '姓名',
    field: 'userName',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '性别',
    field: 'genderName',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: [
        {
          label: '男',
          value: '男',
        },
        {
          label: '女',
          value: '女',
        },
      ],
    },
    colProps: { span: 6 },
  },
  {
    label: '学号',
    field: 'studentId',
    component: 'Input',
    colProps: { span: 6 },
  },

  {
    label: '留宿时间',
    field: 'stayTime',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      valueFormat: 'YYYY-MM-DD',
    },
    colProps: { span: 12 },
  },
];
