import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';

export const columns: BasicColumn[] = [
  {
    title: '奖学金名称',
    dataIndex: 'name',
  },
  {
    title: '奖学金总金额',
    dataIndex: 'totalAmount',
  },
  {
    title: '奖学金来源',
    dataIndex: 'scholarshipSourceCn',
  },
  {
    title: '奖学金等级',
    dataIndex: 'scholarshipLevel',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'scholarshipName',
    label: '奖学金名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'scholarshipSource',
    label: '奖学金来源',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'scholarshipLevel',
    label: '奖学金等级',
    component: 'Input',
    colProps: { span: 8 },
  },
];
// export导出
// import 导出
export const FromSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'name',
    label: '奖学金名称',
    component: 'Input',
    colProps: { span: 24 },
    required: true,
  },
  {
    field: 'scholarshipSource',
    label: '奖学金来源',
    // APi请求下拉框
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: getDataOption,
      params: { code: 'scholarship_source' },
    },
    colProps: { span: 24 },
  },
  {
    field: 'baseSemesterId',
    label: '所属学期',
    required: true,
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: 'baseData/semester/option' },
    },

    colProps: { span: 24 },
  },
  {
    field: 'totalAmount',
    label: '总金额',
    required: true,
    component: 'InputNumber',
    colProps: { span: 24 },
  },
  {
    field: 'scholarshipLevel',
    label: '奖学金等级',
    component: 'Select',
    required: true,
    componentProps: ({ formModel }) => {
      return {
        options: [
          {
            label: '无等级',
            value: 0,
          },
          {
            label: '2级',
            value: 2,
          },
          {
            label: '3级',
            value: 3,
          },
          {
            label: '4级',
            value: 4,
          },
          {
            label: '5级',
            value: 5,
          },
        ],
        onChange: (e) => {
          formModel.baseStudentScholarshipLevelList = [];
          if (e === 0) {
            formModel.baseStudentScholarshipLevelList = [
              {
                amount: '',
                level: '无等级',
              },
            ];
            return;
          }
          //   for of

          for (let i = 0; i < e; i++) {
            formModel.baseStudentScholarshipLevelList.push({
              amount: '',
              level: i + 1,
            });
          }
        },
      };
    },
    colProps: { span: 24 },
  },

  {
    field: 'baseStudentScholarshipLevelList',
    label: '金额',
    required: true,
    component: 'InputNumber',
    slot: 'score',
    colProps: { span: 24 },
  },
];
export const moneyColumns: BasicColumn[] = [
  {
    title: '等级',
    dataIndex: 'level',
  },
  {
    title: '金额',
    dataIndex: 'money',
    align: 'center',
    slots: {
      customRender: 'money',
    },
  },
  {
    title: '单位',
    dataIndex: 'unit',
    align: 'center',
    customRender: ({}) => {
      return '元/每人';
    },
  },
];
