import { BasicColumn, FormSchema } from '/@/components/Table';
export const assessmentTypeOptions = [
  { label: '个人', value: 'personal' },
  { label: '班级', value: 'class' },
];

export const TableColumns: BasicColumn[] = [
  {
    title: '考核细则',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '考核对象',
    dataIndex: 'assessmentType',
    width: 100,
    customRender: ({ text }) => {
      return text === 'personal' ? '个人' : '班级';
    },
  },
  {
    title: '分数',
    dataIndex: 'basicPoints',
    width: 80,
  },
  {
    title: '影响学生',
    dataIndex: 'isAffect',
    customRender: ({ text }) => {
      return text === 1 ? '影响' : '不影响';
    },
    width: 100,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '考核项目',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'isAffect',
    label: '影响操行',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '影响', value: '1' },
        { label: '不影响', value: '0' },
      ],
      getPopupContainer: () => document.body,
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '考核细则',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '分数',
    field: 'basicPoints',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '考核对象',
    field: 'assessmentType',
    component: 'Select',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      options: assessmentTypeOptions,
    },
  },
  {
    label: '响学生操行分',
    field: 'isAffect',
    component: 'RadioButtonGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        { label: '不影响', value: 0 },
        { label: '影响', value: 1 },
      ],
      numberToString: true,
    },
    colProps: { span: 24 },
  },
];
