import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
export const type = {
  0: '菜单',
  1: '目录',
};

export const status = {
  1: '是',
  0: '否',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '职务',
    dataIndex: 'post',
  },
  {
    title: '级别',
    dataIndex: 'levelCn',
  },
  {
    title: '职责描述',
    dataIndex: 'explains',
  },
  {
    title: '是否允许德育检查',
    dataIndex: 'isAllowedCheck',
    customRender: ({ text }) => {
      return status[text];
    },
  },
  {
    title: '排序',
    dataIndex: 'sortCode',
  },
  {
    title: '是否启用',
    dataIndex: 'status',
    customRender: ({ text }) => {
      return status[text];
    },
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    label: '职务名称',
    field: 'post',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'level',
    label: '职务级别',
    component: 'ApiSelect',
    colProps: { span: 24 },
    required: true,
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: () => {
          return getDataOption({ code: 'cadreLevel' });
        },
      };
    },
    // 挂载到body
  },
  {
    label: '是否允许德育检查',
    field: 'isAllowedCheck',
    component: 'RadioGroup',
    defaultValue: 1,
    ifShow: (renderCallbackParams) => {
      return renderCallbackParams.model.level !== 'cadreLevel_class';
    },
    componentProps: {
      options: [
        {
          label: '允许',
          value: 1,
        },
        {
          label: '不允许',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '是否启用',
    field: 'status',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '启用',
          value: 1,
        },
        {
          label: '不启用',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '排序',
    field: 'sortCode',
    component: 'InputNumber',
    defaultValue: 0,
    colProps: { span: 24 },
  },
  {
    label: '职责描述',
    field: 'explains',
    component: 'InputTextArea',
    componentProps: {
      maxLength: 200,
    },
    colProps: { span: 24 },
  },
];
