import { BasicColumn, FormSchema } from '/@/components/Table';
import { getBasestudentcadreClasslist } from '/@/services/apis/BaseStudentCadreController';
export const type = {
  0: '菜单',
  1: '目录',
};

export const status = {
  1: '在职',
  0: '离职',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '学生学号',
    dataIndex: 'studentId',
  },
  {
    title: '学生姓名',
    dataIndex: 'userName',
  },
  {
    title: '职务',
    dataIndex: 'post',
  },
  {
    title: '任职开始时间',
    dataIndex: 'startTime',
  },
  {
    title: '任职结束时间',
    dataIndex: 'endTime',
  },
  {
    title: '是否在职',
    dataIndex: 'status',
    customRender: ({ text }) => {
      return status[text];
    },
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'status',
    label: '状态',
    component: 'RadioGroup',
    colProps: { span: 24 },
    required: true,
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '在职',
          value: 1,
        },
        {
          label: '离职',
          value: 0,
        },
      ],
    },
  },
  {
    field: 'leaveReason',
    label: '离职原因',
    component: 'InputTextArea',
    colProps: { span: 24 },
    required: true,
    ifShow: ({ values }) => {
      return values.status === 0;
    },
  },
  {
    field: 'leaveTime',
    label: '离职生效日期',
    component: 'DatePicker',
    colProps: { span: 24 },
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
      showTime: false,
    },
    required: true,
    ifShow: ({ values }) => {
      return values.status === 0;
    },
  },
  {
    field: 'startTime',
    label: '任职开始时间',
    component: 'DatePicker',
    colProps: { span: 24 },
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
      showTime: false,
    },
    required: true,
  },
  {
    field: 'endTime',
    label: '任职结束时间',
    component: 'DatePicker',
    colProps: { span: 24 },
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
      showTime: false,
    },
  },
];

export const studentTableColumns: BasicColumn[] = [
  {
    title: '学生姓名',
    dataIndex: 'name',
  },
  {
    title: '学生学号',
    dataIndex: 'userName',
  },
  {
    title: '任职开始时间',
    dataIndex: 'startTime',
    slots: { customRender: 'startTime' },
  },
  {
    title: '任职结束时间',
    dataIndex: 'endTime',
    slots: { customRender: 'endTime' },
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    label: '班级列表',
    field: 'classId',
    component: 'ApiSelect',
    defaultValue: '',
    componentProps: ({ formModel }) => {
      return {
        api: async () => {
          const data = await getBasestudentcadreClasslist({});
          formModel.classId = data[0].id;
          return data;
        },
        showSearch: true,
        treeNodeFilterProp: 'name',
        labelField: 'name',
        // use id as value
        valueField: 'id',
      };
    },
  },
];
