import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';

export const tableColumns: BasicColumn[] = [
  {
    title: '学号',
    dataIndex: 'studentId',
    align: 'left',
  },
  {
    title: '姓名',
    dataIndex: 'name',
    align: 'left',
    width: 80,
  },
  {
    title: '性别',
    dataIndex: 'genderCn',
    width: 80,
  },
  {
    title: '联系方式',
    dataIndex: 'phone',
    align: 'left',
    width: 120,
  },
  {
    title: '学籍状态',
    dataIndex: 'archivesStatusCn',
    width: 80,
  },
  {
    title: '就读方式',
    dataIndex: 'stduyStatusCn',
    width: 80,
  },
  {
    title: '学习形式',
    dataIndex: 'rollModalityCn',
    width: 80,
  },
  {
    title: '是否发放毕业证',
    dataIndex: 'status',
    customRender: ({ record }) => {
      return record.status === 1 ? '是' : '否';
    },
    width: 120,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'archivesStatus',
    label: '学籍状态',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'archives_status' });
      },
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'stduyStatus',
    label: '就读方式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'stduy_status' });
      },
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'rollModality',
    label: '学习形式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'roll_modality' });
      },
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'status',
    label: '发放毕业证',
    component: 'Select',
    componentProps: {
      options: [
        { label: '已发放', value: '1' },
        { label: '未发放', value: '0' },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '学生',
    field: 'name',
    component: 'Input',
    colProps: { span: 12 },
    dynamicDisabled: true,
  },
  {
    label: '年级',
    field: 'gradeName',
    component: 'Input',
    colProps: { span: 12 },
    dynamicDisabled: true,
  },
  {
    label: '班级',
    field: 'className',
    component: 'Input',
    colProps: { span: 12 },
    dynamicDisabled: true,
  },
  {
    label: '专业',
    field: 'majorName',
    component: 'Input',
    colProps: { span: 12 },
    dynamicDisabled: true,
  },
  {
    label: '就读方式',
    field: 'stduyStatusCn',
    component: 'Input',
    colProps: { span: 24 },
    dynamicDisabled: true,
  },
  {
    label: '证书编号',
    field: 'certificateNumber',
    component: 'Input',
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '是否发放证书',
    field: 'status',
    component: 'Select',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      options: [
        { label: '已发放', value: 1 },
        { label: '未发放', value: 0 },
      ],
    },
  },
  {
    label: '发证日期',
    field: 'certificateDate',
    component: 'DatePicker',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      format: 'YYYY-MM-DD',
      getPopupContainer: () => document.body,
    },
  },
  {
    label: '离寝日期',
    field: 'leavingBedDate',
    component: 'DatePicker',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      format: 'YYYY-MM-DD',
      getPopupContainer: () => document.body,
    },
  },
  {
    label: '附件',
    field: 'folderId',
    component: 'Upload',
    required: true,
    slot: 'upload',
    colProps: { span: 12 },
  },
];
export const EditInfoFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 24 },
    required: true,
    slot: 'name',
  },
  {
    field: 'gradeName',
    label: '年级',
    component: 'Input',
    colProps: { span: 24 },
    slot: 'gradeName',
  },
  {
    field: 'majorName',
    label: '专业',
    slot: 'majorName',
    component: 'Input',
    colProps: { span: 24 },
    required: true,
  },
  {
    label: '学习形式',
    field: 'rollModality',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: () => {
        return getDataOption({ code: 'roll_modality' });
      },
    },
    colProps: { span: 24 },
    required: true,
  },
  {
    label: '就读方式',
    field: 'stduyStatus',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: () => {
        return getDataOption({ code: 'stduy_status' });
      },
    },
    colProps: { span: 24 },
    required: true,
  },
];
