import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { getDataOption } from '/@/api/system/dic';
import { requestMagicApi } from '/@/api/magicApi';
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'scholarshipSource',
    label: '学籍异动类型',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: getDataOption,
        params: { code: 'school_change_type' },
        onChange: () => {
          formModel.schoolRollCategoryId = undefined;
          formModel.schoolRollReasonId = undefined;
        },
      };
    },
  },
  {
    field: 'schoolRollCategoryId',
    label: '学籍异动类别',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: {
          url: `student/schoolRollCategory/option?scholarship_source=${formModel.scholarshipSource}`,
        },
        onChange: () => {
          formModel.schoolRollReasonId = undefined;
        },
      };
    },
  },
  {
    field: 'schoolRollReasonId',
    label: '学籍异动原因',
    colProps: { span: 8 },
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: {
          url: `student/schoolRollReason/option?school_roll_category_id=${formModel.schoolRollCategoryId}`,
        },
      };
    },
  },
];
export const columns: BasicColumn[] = [
  {
    title: '申请人',
    dataIndex: 'applicantUserName',
  },
  {
    title: '异动学生姓名',
    dataIndex: 'name',
  },
  {
    title: '学号',
    dataIndex: 'studentId',
  },
  {
    title: '学籍异动类型',
    dataIndex: 'scholarshipSourceCn',
  },
  {
    title: '入（离）班时间',
    dataIndex: 'inClassDate',
    customRender: ({ record }) => {
      return record.inClassDate || record.outClassDate;
    },
  },
  {
    title: '异动前班级',
    dataIndex: 'beforeClassName',
  },
  {
    title: '生效状态',
    dataIndex: 'status',
    customRender: ({ text }) => {
      return text === 0
        ? h('span', { style: 'color: red' }, '未生效')
        : h('span', { style: 'color: green' }, '已生效');
    },
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];

export const enum showConfig {
  applicantUserName = '申请人',
  scholarshipSourceCn = '学籍异动类型',
  name = '异动学生姓名',
  beforeMajorSetName = '异动前专业方向',
  beforeGradeName = '异动前入学年级',
  beforeDepartmentName = '异动前所属机构',
  beforeClassName = '异动前班级',
  backClassName = '异动后班级',
  backDepartmentName = '异动后所属机构',
  backGradeName = '异动后入学年级',
  backMajorSetName = '异动后专业方向',
  inClassDate = '入班时间',
  outClassDate = '离班时间',
  leaveYear = '休学年限',
  leaveStartYear = '休学开始时间',
  leaveEndYear = '休学结束时间',
  gender = '性别',
  reason = '原因',
  status = '变更状态',
  isRecord = '是否恢复账号',
  isRetain = '是否保留学籍',
  isUnderGraduate = '是否保留学籍',
  isMaintained = '是否维护到国家/省学籍系统',
  remark = '备注',
}
