import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { getAreaOption, getClassOption, getGradeOption, getMajorSetOption } from '/@/api/userMagic';

export const columns1: BasicColumn[] = [
  {
    title: '姓名',
    dataIndex: 'name',
    slots: { customRender: 'name' },
  },
  {
    title: '性别',
    dataIndex: 'genderCn',
  },
  {
    title: '是否为监护人',
    dataIndex: 'isGuardian',
    customRender: ({ text }) => {
      return text === 1 ? '是' : '否';
    },
  },
  {
    title: '出生日期',
    dataIndex: 'dayOfBirth',
  },
  {
    title: '政治面貌',
    dataIndex: 'politicalState',
    width: 200,
  },
  {
    title: '职业',
    dataIndex: 'occupation',
  },
  {
    title: '工作单位',
    dataIndex: 'workUnit',
  },
  {
    title: '联系电话',
    dataIndex: 'mobile',
  },
  {
    title: '操作',
    dataIndex: 'action',
    align: 'center',
    slots: { customRender: 'action' },
  },
];
export const drwFormSchema: FormSchema[] = [
  {
    field: 'relationship',
    label: '与本人关系',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'relationship' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'gender',
    label: '性别',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 7 },
  },
  {
    field: 'dayOfBirth',
    label: '出生日期',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'birthType',
    label: '生日类型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'date_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'nation',
    label: '民族',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'nation' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'workUnit',
    label: '工作单位',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'occupation',
    label: '从事的工作(职业)',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'position',
    label: '职务',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'mobile',
    label: '联系电话',
    rules: [
      {
        // 校验手机号
        pattern: /^1[3456789]\d{9}$/,
        message: '手机号格式错误',
        trigger: 'blur',
      },
    ],
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'isGuardian',
    label: '是否为监护人',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'credentialType',
    label: '证件类型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'credential_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'credentialNumber',
    label: '证件号码',
    component: 'InputNumber',
    colProps: { span: 7 },
  },
  {
    field: 'politicalState',
    label: '政治面貌',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'political_state' });
      },
    },
    colProps: { span: 7 },
  },
  //   校验数字正则 /^[0-9]*$/

  {
    field: 'health',
    label: '健康状况',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'health' });
      },
    },
  },
  {
    field: 'houseProvinces',
    label: '户口所在地 省',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          return getAreaOption({ parent_id: 0 });
        },
        onChange: () => {
          formModel.city = undefined;
          formModel.district = undefined;
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseCity',
    label: '户口所在地市',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.houseProvinces) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.houseProvinces });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseDistrict',
    label: '户口所在地区/县',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.houseCity) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.houseCity });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'email',
    label: '电子邮箱',
    component: 'Input',
    rules: [
      {
        // 校验邮箱
        pattern: /^([a-zA-Z]|[0-9])(\w|\-)+@[a-zA-Z0-9]+\.([a-zA-Z]{2,4})$/,
        message: '邮箱格式错误',
        trigger: 'blur',
      },
      {
        message: '请输入邮箱',
        trigger: 'blur',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'wechat',
    label: '微信号',
    component: 'Input',
    colProps: { span: 7 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'studentId',
    label: '学号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'mobile',
    label: '手机号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const columns: BasicColumn[] = [
  {
    dataIndex: 'studentId',
    title: '学号',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'mobile',
    title: '手机号',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'name',
    title: '姓名',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'email',
    title: '邮箱',
    componentType: 'input',

    sorter: true,
  },
];

export const fromSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'studentId',
    label: '学号',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'gender',
    label: '性别',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 7 },
  },
  {
    field: 'mobile',
    label: '手机号',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    rules: [
      {
        message: '请输入邮箱',
        trigger: 'blur',
      },
      {
        type: 'email',
        message: '请输入正确的邮箱地址',
        trigger: ['change', 'blur'],
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'asName',
    label: '别名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'enName',
    label: '英文名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'pyName',
    label: '姓名拼音',
    component: 'Input',
    rules: [
      {
        // 正则校验是否为英文
        pattern: /^[a-zA-Z]+$/,
        message: '请输入英文',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'formerName',
    label: '曾用名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'credentialType',
    label: '证件类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'credential_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'credentialNumber',
    label: '证件号码',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'dayOfBirth',
    label: '出生日期',
    component: 'DatePicker',
    required: true,
    componentProps: {
      valueFormat: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'birthType',
    label: '生日类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'date_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'nation',
    label: '民族',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'nation' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'bloodType',
    label: '血型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'blood_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'health',
    label: '健康状况',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'health' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'maritalState',
    label: '婚姻状况',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'marital_state' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'politicalState',
    label: '政治面貌',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'political_state' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'nationality',
    label: '国籍地区',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'nationality' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'chineseType',
    label: '港澳台侨外',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'chinese_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseHoldType',
    label: '户口类别',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'house_hold_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'provinces',
    label: '籍贯省份',
    component: 'ApiSelect',
    componentProps: ({ formActionType, formModel }) => {
      return {
        api: () => {
          return getAreaOption({ parent_id: 0 });
        },
        onChange: (value: any) => {
          const { updateSchema } = formActionType;
          formModel.city = undefined;
          formModel.district = undefined;
          updateSchema({
            field: 'district',
            component: 'Select',
            componentProps: {
              options: [],
            },
          });
          updateSchema({
            field: 'city',
            component: 'ApiSelect',
            componentProps: {
              api: () => {
                return getAreaOption({ parent_id: value });
              },
              onChange: (value: any) => {
                const { updateSchema } = formActionType;
                formModel.district = undefined;
                updateSchema({
                  field: 'district',
                  component: 'ApiSelect',
                  componentProps: {
                    api: () => {
                      return getAreaOption({ parent_id: value });
                    },
                  },
                });
              },
            },
          });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'city',
    label: '市',
    component: 'Select',
    componentProps: {},
    colProps: { span: 7 },
  },
  {
    field: 'district',
    label: '区/县',
    component: 'Select',
    componentProps: {},
    colProps: { span: 7 },
  },

  {
    field: 'houseProvinces',
    label: '户口所在地 省',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          return getAreaOption({ parent_id: 0 });
        },
        onChange: () => {
          formModel.city = undefined;
          formModel.district = undefined;
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseCity',
    label: '户口所在地市',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.houseProvinces) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.houseProvinces });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseDistrict',
    label: '户口所在地区/县',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.houseCity) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.houseCity });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'belongsPolice',
    label: '户口所属派出所',
    component: 'Input',
    componentProps: {},
    colProps: { span: 7 },
  },

  {
    field: 'birthProvinces',
    label: '出生所在地 省',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          return getAreaOption({ parent_id: 0 });
        },
        onChange: () => {
          formModel.city = undefined;
          formModel.district = undefined;
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'birthCity',
    label: '出生所在地市',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.birthProvinces) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.birthProvinces });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'birthDistrict',
    label: '出生所在地区/县',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.birthCity) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.birthCity });
        },
      };
    },
    colProps: { span: 7 },
  },

  {
    field: 'houseHoldAddress',
    label: '户籍地址',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'residenceType',
    label: '学生居住地类型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'residence_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'trainInterval',
    label: '乘火车区间',
    component: 'Input',
    componentProps: {},
    colProps: { span: 7 },
  },
  {
    field: 'isMigrateChildren',
    label: '是否随迁子女',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'isFloatingPopulation',
    label: '是否流动人口',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'height',
    label: '身高',
    component: 'InputNumber',
    componentProps: {},
    colProps: { span: 7 },
  },
  {
    field: 'weight',
    label: '体重',
    component: 'InputNumber',
    componentProps: {},
    colProps: { span: 7 },
  },
  {
    field: 'vision',
    label: '视力',
    component: 'InputNumber',
    componentProps: {},
    colProps: { span: 7 },
  },
  {
    field: 'specialty',
    label: '特长',
    component: 'Input',
    componentProps: {},
    colProps: { span: 7 },
  },
];

export const contactSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'qqMsn',
    label: 'QQ&MSN',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'wechat',
    label: '微信号',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'userPage',
    label: '个人主页',
    component: 'Input',
    colProps: { span: 7 },
  },
];

export const schoolRoll: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'rollNumber',
    label: '学籍号',
    component: 'InputNumber',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'archivesNumber',
    label: '学生档案编号',
    required: true,
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'enrollmentDate',
    label: '入学年月',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'enrollmentType',
    label: '入学方式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'enrollment_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'gradeId',
    label: '入学年级',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getGradeOption();
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'enrollType',
    label: '入学招生类型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'enroll_type' });
      },
    },
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'majorSetId',
    label: '在读专业方向',
    component: 'ApiSelect',
    required: true,
    componentProps: ({ formModel }) => {
      return {
        api: getMajorSetOption,
        onChange: (value) => {
          const data = getMajorSetOption();
          data.then((res) => {
            // 查询value 与Id相同的year
            formModel.studyYear = res.find((item) => item.value === value)?.year;
          });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'studyYear',
    label: '学制',
    component: 'Input',
    dynamicDisabled: true,
    colProps: { span: 7 },
  },
  {
    field: 'classId',
    label: '班级',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getClassOption();
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'studentSource',
    label: '学生来源',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'student_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'studentType',
    label: '学生类别',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'student_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'archivesStatus',
    label: '学籍状态',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'archives_status' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'rollModality',
    label: '学习形式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'roll_modality' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'stduyStatus',
    label: '就读方式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'stduy_status' });
      },
    },
    colProps: { span: 7 },
  },
  // {
  //   field: 'learnStatus',
  //   label: '学习形式',
  //   component: 'ApiSelect',
  //   componentProps: {
  //     api: () => {
  //       return getDataOption({ code: 'learn_status' });
  //     },
  //   },
  //   colProps: { span: 7 },
  // },
  {
    field: 'chooseStatus',
    label: '分流状态',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'choose_status' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'fosterType',
    label: '分段培养方式',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'foster_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'recruitType',
    label: '招生类型',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'recruit_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'recruitTarget',
    label: '招生对象',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'recruit_target' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'highestEducation',
    label: '入学前最高学历',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'education' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'graduatedUniversity',
    label: '入学前毕业院校',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'graduatedScore',
    label: '入学前毕业成绩',
    component: 'Input',
    rules: [
      {
        // 整数或最多两位小数
        pattern: /^([1-9]\d*|0)(\.\d{1,2})?$/,
        message: '请输入整数或最多两位小数',
        trigger: 'blur',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'examineeNumber',
    label: '入学考试考生号',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'ticketNumber',
    label: '入学考试准考证号',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'admissionScores',
    label: '入学考试成绩',
    component: 'Input',
    rules: [
      {
        // 整数或最多两位小数
        pattern: /^([1-9]\d*|0)(\.\d{1,2})?$/,
        message: '请输入整数或最多两位小数',
        trigger: 'blur',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'remark',
    label: '备注',
    component: 'InputTextArea',
    colProps: { span: 7 },
  },
];

export const subsidizeSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'isIndemnify',
    label: '是否低保户',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'isStipend',
    label: '是否享受国家助学金',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },

  {
    field: 'stipendStand',
    label: '助学金发放标准（元）',
    component: 'InputNumber',
    colProps: { span: 7 },
  },
  {
    field: 'stipendNumber',
    label: '学生资助卡号',
    component: 'Input',
    rules: [
      {
        pattern: /^[0-9]*$/,
        message: '请输入数字',
        trigger: 'blur',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'isFree',
    label: '是否免学费',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'isFilingCard',
    label: '是否建档立卡',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
];

export const familySchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'zipCode',
    label: '家庭邮编',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'telephone',
    label: '家庭电话',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'contact',
    label: '联系人姓名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'population',
    label: '家庭人口',
    component: 'InputNumber',
    colProps: { span: 7 },
  },
  {
    field: 'address',
    label: '家庭住址',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'incomeSource',
    label: '家庭主要收入来源',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'incomeNumber',
    label: '家庭月收入（元）',
    component: 'Input',
    rules: [
      {
        //校验是否是数字或者小数
        pattern: /^([1-9]\d*|[0]{1,1})$|^([1-9]\d*|[0]{1,1})\.\d{1,2}$/,
        message: '请输入数字或者小数',
        trigger: 'blur',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'railwayStation',
    label: '离家最近火车站',
    component: 'Input',
    colProps: { span: 7 },
  },
];
