import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { getAreaOption, getMajorOption, getSubjectOption } from '/@/api/userMagic';

export const sexOptions = [
  {
    label: '男',
    value: 1,
  },
  {
    label: '女',
    value: 0,
  },
];

export const columns1: BasicColumn[] = [
  {
    title: '姓名',
    dataIndex: 'name',
    slots: { customRender: 'name' },
  },
  {
    title: '性别',
    dataIndex: 'gender',
    slots: { customRender: 'gender' },
  },
  {
    title: '是否为监护人',
    dataIndex: 'isGuardian',
    slots: { customRender: 'is_guardian' },
  },
  {
    title: '出生日期',
    dataIndex: 'dayOfBirth',
    slots: { customRender: 'day_of_birth' },
  },
  {
    title: '政治面貌',
    dataIndex: 'politicalState',
    width: 200,
    slots: { customRender: 'political_state' },
  },
  {
    title: '职业',
    dataIndex: 'occupation',
    slots: { customRender: 'occupation' },
  },
  {
    title: '工作单位',
    dataIndex: 'workUnit',
    slots: { customRender: 'work_unit' },
  },
  {
    title: '联系电话',
    dataIndex: 'mobile',
    slots: { customRender: 'mobile' },
  },
  {
    title: '操作',
    dataIndex: 'action',
    align: 'center',
    slots: { customRender: 'action' },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'userName',
    label: '工号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'mobile',
    label: '手机号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const columns: BasicColumn[] = [
  {
    dataIndex: 'userName',
    title: '工号',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'mobile',
    title: '手机号',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'name',
    title: '姓名',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'email',
    title: '邮箱',
    componentType: 'input',

    sorter: true,
  },
];

export const baseFromSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'userName',
    label: '工号',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'mobile',
    label: '手机号',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'gender',
    label: '性别',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'gender' },
    },
    colProps: { span: 7 },
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入邮箱',
        trigger: 'blur',
      },
      {
        type: 'email',
        message: '请输入正确的邮箱地址',
        trigger: ['change', 'blur'],
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'asName',
    label: '别名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'enName',
    label: '英文名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'pyName',
    label: '姓名拼音',
    component: 'Input',
    rules: [
      {
        // 正则校验是否为英文
        pattern: /^[a-zA-Z]+$/,
        message: '请输入英文',
      },
    ],
    colProps: { span: 7 },
  },
  {
    field: 'formerName',
    label: '曾用名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'jobState',
    label: '在职状态',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'job_state' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'credentialType',
    label: '证件类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'credential_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'credentialNumber',
    label: '证件号码',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'dayOfBirth',
    label: '出生日期',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'birthType',
    label: '生日类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'date_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'nation',
    label: '民族',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'nation' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'bloodType',
    label: '血型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'blood_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'maritalState',
    label: '健康状况',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'health' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'politicalState',
    label: '政治面貌',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'political_state' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'nationality',
    label: '国籍地区',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'nationality' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'chineseType',
    label: '港澳台侨外',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'chinese_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseHoldType',
    label: '户口类别',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getDataOption({ code: 'house_hold_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'provinces',
    label: '省份',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          return getAreaOption({ parent_id: 0 });
        },
        onChange: () => {
          formModel.city = undefined;
          formModel.district = undefined;
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'city',
    label: '市',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.provinces) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.provinces });
        },
        onChange: () => {
          formModel.district = undefined;
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'district',
    label: '区/县',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: () => {
          if (!formModel.city) return Promise.resolve({ data: [] });
          return getAreaOption({ parent_id: formModel.city });
        },
      };
    },
    colProps: { span: 7 },
  },
  {
    field: 'houseHoldAddress',
    label: '户籍地址',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'startWorkTime',
    label: '参加工作时间',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'joinTime',
    label: '来校时间',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'employType',
    label: '聘用类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'employ_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'employWay',
    label: '聘用方式',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'employ_type' });
      },
    },
    colProps: { span: 7 },
  },
];

export const contactFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'officeTel',
    label: '办公室电话',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'officeAddress',
    label: '办公室地址',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'address',
    label: '现住地址',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'qqMsn',
    label: 'QQ&MSN',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'wechat',
    label: '微信号',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'microblog',
    label: '微博地址',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'zipCode',
    label: '住址邮编',
    component: 'Input',
    colProps: { span: 7 },
  },
];

export const regularFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'certificateType',
    label: '教师资格证种类',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'certificate_type' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'belongOrg',
    label: '所属系统',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'belong_org' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'mandarinLevel',
    label: '普通话等级',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'mandarin_level' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'startTeachTime',
    label: '从教起始年月',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    colProps: { span: 7 },
  },
  {
    field: 'teachingStatus',
    label: '任课状况',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      mode: 'multiple',
      api: () => {
        return getDataOption({ code: 'teaching_status' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'majorCategorId',
    label: '任教学科类别',
    component: 'ApiSelect',
    componentProps: {
      api: () => {
        return getMajorOption();
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'isDoubleTeacher',
    label: '是否双师型教师',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        { label: '是', value: 1 },
        { label: '否', value: 0 },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'courseSubjectId',
    label: '任教学科',
    component: 'ApiSelect',
    colProps: { span: 7 },
    componentProps: {
      api: () => {
        return getSubjectOption();
      },
    },
  },
];

export const educationFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'specialty',
    label: '所学专业',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'education',
    label: '最高学历',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'education' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'educationCollege',
    label: '最高学历的院校',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
  {
    field: 'degree',
    label: '最高学位',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: () => {
        return getDataOption({ code: 'degree' });
      },
    },
    colProps: { span: 7 },
  },
  {
    field: 'degreeCollege',
    label: '最高学位的院校',
    component: 'Input',
    required: true,
    colProps: { span: 7 },
  },
];

export const familyFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'zipCode',
    label: '家庭邮编',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'telephone',
    label: '家庭电话',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'contact',
    label: '联系人姓名',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'population',
    label: '家庭人口',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'address',
    label: '家庭住址',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'finance',
    label: '家庭经济情况',
    component: 'Input',
    colProps: { span: 7 },
  },
];
