import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';

import { postEvaluateTemplateChangeStatus } from '/@/services/apis/EvaluateTemplateController';
import { useMessage } from '/@/hooks/web/useMessage';

import { requestMagicApi } from '/@/api/magicApi';

export const tableColumns: BasicColumn[] = [
  {
    title: '模板名称',
    dataIndex: 'name',
    align: 'left',
    width: 200,
  },
  {
    title: '评价类型',
    dataIndex: 'evaluateType',
    align: 'left',
    width: 120,
  },
  {
    title: '使用部门',
    dataIndex: 'deptNames',
    align: 'left',
    width: 150,
  },
  {
    title: '评价分数',
    dataIndex: 'total',
    width: 80,
  },
  {
    title: '说明',
    dataIndex: 'remark',
    align: 'left',
  },
  {
    title: '状态',
    dataIndex: 'status',
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.status === 1,
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',
        loading: record.pendingStatus,
        onChange(checked: boolean) {
          record.pendingStatus = true;
          const newStatus = checked ? 1 : 0;
          const { createMessage } = useMessage();
          postEvaluateTemplateChangeStatus({ id: record.id, status: newStatus })
            .then(() => {
              record.status = newStatus;
              createMessage.success('已成功修改角色状态');
            })
            .catch(() => {
              createMessage.error('修改角色状态失败');
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
    width: 90,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'deptIds',
    label: '使用部门',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        multiple: true,
        api: async () => {
          const data = await requestMagicApi({ url: 'educational/abutment/org-info' });
          const list = data.map((item) => {
            return { value: item.id, label: item.name };
          });
          list.unshift({ value: '0', label: '通用' });
          return list;
        },
      };
    },
  },
  {
    field: 'evaluateType',
    label: '评价类型',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: () => {
        return getDataOption({ code: 'evaluate_type' });
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '模板名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'status',
    label: '状态',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '禁用', value: '0' },
      ],
      getPopupContainer: () => document.body,
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '模板名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '评价类型',
    field: 'evaluateType',
    component: 'ApiSelect',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      api: () => {
        return getDataOption({ code: 'evaluate_type' });
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    label: '使用部门',
    field: 'deptIds',
    required: true,
    component: 'ApiSelect',
    colProps: { span: 12 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        mode: 'multiple',
        api: async () => {
          const data = await requestMagicApi({ url: 'educational/abutment/org-info' });
          const list = data.map((item) => {
            return { value: item.id, label: item.name };
          });
          list.unshift({ value: '0', label: '通用' });
          return list;
        },
      };
    },
  },
  {
    label: '评价总分',
    field: 'total',
    component: 'InputNumber',
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '备注',
    field: 'remark',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
];

export const formTermSchema: FormSchema[] = [
  {
    label: '标题名称',
    field: 'field0',
    component: 'Input',
    colProps: { span: 22 },
    required: true,
  },
  {
    field: '0',
    component: 'Input',
    label: '',
    colProps: {
      span: 2,
    },
    slot: 'add',
  },
  {
    label: '',
    field: 'table0',
    component: 'Input',
    colProps: { span: 24 },
    required: true,
    slot: 'table',
  },
];

export const tableDetailColumns: BasicColumn[] = [
  {
    title: '题目名称',
    dataIndex: 'problem',
    editRow: true,
    editRule: true,
    align: 'left',
  },
  {
    title: '分数',
    dataIndex: 'score',
    width: 80,
    editRow: true,
    editComponent: 'InputNumber',
  },
  {
    title: '必填',
    dataIndex: 'inputNotNull',
    width: 80,
    editRow: true,
    editComponent: 'Switch',
    editValueMap: (value) => {
      return value ? '是' : '否';
    },
  },
];
