import { h } from 'vue';
import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { getDepartmentTree } from '/@/services/apis/DepartmentController';

export const TableColumns: BasicColumn[] = [
  {
    title: '学期',
    dataIndex: 'semesterName',
    align: 'left',
    width: 150,
  },
  {
    title: '发布部门',
    dataIndex: 'orgName',
    align: 'left',
    width: 120,
  },
  {
    title: '评价类型',
    dataIndex: 'evaluateTypeCn',
    align: 'left',
    width: 150,
  },
  {
    title: '评价名称',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '开始时间',
    dataIndex: 'startTime',
    width: 150,
  },
  {
    title: '结束时间',
    dataIndex: 'endTime',
    width: 150,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 80,
    customRender: ({ text }) => {
      return text === -1
        ? h('span', { style: { color: '#94b3ff' } }, '未发布')
        : text === 1
        ? h('span', { style: { color: 'green' } }, '进行中')
        : h('span', { style: { color: '#ccc' } }, '暂停');
    },
  },
  {
    title: '参与人',
    dataIndex: 'participateNumber',
    slots: { customRender: 'participateNumber' },
    width: 80,
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '评价名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '评价类型',
    field: 'evaluateType',
    component: 'ApiSelect',
    required: true,
    colProps: { span: 12 },
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: getDataOption,
        params: {
          code: 'evaluate_type',
        },
        onChange: () => {
          formModel.evaluateTemplateId = undefined;
        },
      };
    },
  },
  {
    label: '模板名称',
    field: 'evaluateTemplateId',
    component: 'ApiSelect',
    required: true,
    colProps: { span: 12 },
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: {
          url: `educational/evaluate_template/option?evaluate_type=${formModel.evaluateType}`,
        },
      };
    },
  },
  {
    label: '学期',
    field: 'baseSemesterId',
    component: 'ApiSelect',
    colProps: { span: 12 },
    required: true,
    componentProps: () => {
      return {
        api: requestMagicApi,
        getPopupContainer: () => document.body,
        params: {
          url: '/baseData/semester/option',
        },
        showSearch: true,
        filterOption: (input: string, option: any) => {
          return (
            option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
  },
  {
    label: '发布部门',
    field: 'orgId',
    component: 'ApiTreeSelect',
    colProps: { span: 12 },
    required: true,
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: getDepartmentTree,
        fieldNames: {
          label: 'name',
          key: 'id',
          value: 'id',
        },
        treeNodeFilterProp: 'label',
        showSearch: true,
      };
    },
  },
  {
    label: '评价时间',
    field: 'startTime',
    component: 'RangePicker',
    colProps: { span: 24 },
    required: true,
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        placeholder: ['开始时间', '结束时间'],
        format: 'YYYY-MM-DD HH:mm:ss',
        showTime: { format: 'HH:mm:ss' },
      };
    },
  },
  {
    label: '生成评价任务',
    field: 'isAutoCreate',
    component: 'Select',
    colProps: { span: 12 },
    defaultValue: '0',
    componentProps: {
      getPopupContainer: () => document.body,
      numberToString: true,
      options: [
        { label: '开启', value: '1' },
        { label: '关闭', value: '0' },
      ],
    },
  },
  {
    label: '生成规则',
    field: 'createFrequency',
    component: 'ApiSelect',
    colProps: { span: 12 },
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: {
        code: 'create_frequency',
      },
      showSearch: true,
      filterOption: (input: string, option: any) => {
        return (
          option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    ifShow: ({ values }) => {
      return values.isAutoCreate === '1';
    },
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    label: '学期',
    field: 'semesterId',
    component: 'ApiSelect',
    colProps: { span: 6 },
    componentProps: () => {
      return {
        api: requestMagicApi,
        getPopupContainer: () => document.body,
        params: {
          url: '/baseData/semester/option',
        },
        showSearch: true,
        filterOption: (input: string, option: any) => {
          return (
            option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
  },
  {
    label: '部门',
    field: 'orgId',
    component: 'ApiTreeSelect',
    colProps: { span: 6 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: getDepartmentTree,
        fieldNames: {
          label: 'name',
          key: 'id',
          value: 'id',
        },
        showSearch: true,
        treeNodeFilterProp: 'name',
      };
    },
  },
  {
    label: '评价类型',
    field: 'evaluateType',
    component: 'ApiSelect',
    colProps: { span: 6 },
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: {
        code: 'evaluate_type',
      },
    },
  },
  {
    label: '状态',
    field: 'status',
    component: 'Select',
    colProps: { span: 6 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: [
        { label: '未发布', value: -1 },
        { label: '进行中', value: 1 },
        { label: '已结束', value: 0 },
      ],
    },
  },
  {
    label: '名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '时间',
    field: 'time',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
    },
    colProps: { span: 12 },
  },
];

export const showConfig: FormSchema[] = [
  {
    label: '评价类型',
    field: 'evaluateType',
    component: 'ApiSelect',
    colProps: { span: 8 },
    required: true,
    dynamicDisabled: true,
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: {
        code: 'evaluate_type',
      },
    },
  },
  {
    label: '年级',
    field: 'gradeId',
    component: 'ApiSelect',
    colProps: { span: 8 },
    required: true,
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: {
        url: '/baseData/grade/option',
      },
    },
  },
  {
    label: '学生选择',
    field: 'executerCount',
    component: 'Select',
    required: true,
    colProps: { span: 8 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: [
        { label: '全部', value: 'all' },
        { label: '随机15人', value: 'random15' },
      ],
    },
    ifShow: ({ values }) => {
      return (
        values.evaluateType === 'stu_evaluate_headtea' || values.evaluateType === 'stu_evaluate_tea'
      );
    },
  },
];
