import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { getDepartmentTree } from '/@/services/apis/DepartmentController';
//评价结果里面的表格字段
export const tableColumns: BasicColumn[] = [
  {
    title: '学期',
    dataIndex: 'semesterName',
    align: 'left',
    width: 100,
  },
  {
    title: '发布部门',
    dataIndex: 'orgName',
    align: 'left',
    width: 150,
  },
  {
    title: '评价类型',
    dataIndex: 'evaluateTypeCN',
    align: 'left',
    width: 120,
  },
  {
    title: '评价名称',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '开始时间',
    dataIndex: 'startTime',
    width: 150,
  },
  {
    title: '结束时间',
    dataIndex: 'endTime',
    width: 150,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 180,
  },
];
//评价结果里面的搜索字段
export const SearchFormSchema: FormSchema[] = [
  {
    label: '学期',
    field: 'baseSemesterId',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,

        api: requestMagicApi,
        params: {
          url: '/baseData/semester/option',
        },
        showSearch: true,
        filterOption: (input: string, option: any) => {
          return (
            option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
  },
  {
    label: '部门',
    field: 'orgId',
    component: 'ApiTreeSelect',
    colProps: { span: 8 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: getDepartmentTree,
        fieldNames: {
          label: 'name',
          key: 'id',
          value: 'id',
        },
        showSearch: true,
        treeNodeFilterProp: 'name',
      };
    },
  },
  {
    label: '评价类型',
    field: 'evaluateType',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: {
        code: 'evaluate_type',
      },
    },
  },
  {
    label: '名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    label: '时间',
    field: '[startTime,endTime]',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: { format: 'HH:mm' },
    },
    colProps: { span: 8 },
  },
];
//详情查看按钮模态框里面的表格字段
export const detailTableColumns: BasicColumn[] = [
  {
    title: '被评对象',
    dataIndex: 'ObjectIdCN',
    align: 'left',
  },
  {
    title: '参评人',
    dataIndex: 'userIdCN',
    width: 120,
    align: 'left',
  },
  {
    title: '评分状态',
    dataIndex: 'status',
    width: 80,
  },
  {
    title: '综合评分',
    dataIndex: 'comprehensiveScore',
    width: 80,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 80,
  },
];

//详情查看按钮模态框里面的搜索字段
export const detailSearchFormSchema: FormSchema[] = [
  // {
  //   label: '学期',
  //   field: 'baseSemesterId',
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: () => {
  //     return {
  //       api: requestMagicApi,
  //       getPopupContainer: () => document.body,
  //       params: {
  //         url: '/baseData/semester/option',
  //       },
  //       showSearch: true,
  //       filterOption: (input: string, option: any) => {
  //         return (
  //           option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
  //           option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
  //         );
  //       },
  //     };
  //   },
  // },
  {
    field: 'baseGradeId',
    label: '年级',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'baseData/grade/option' },
    },
    colProps: { span: 8 },
  },
  {
    field: 'teacherId',
    label: '任课教师',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'educational/abutment/teacher-info' },
      fieldNames: { label: 'name', value: 'id' },
    },
    colProps: { span: 8 },
  },
  {
    field: 'classId',
    label: '班级',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'educational/class/option' },
    },
    colProps: { span: 8 },
  },
  {
    field: 'status',
    label: '是否评分',
    component: 'Select',
    componentProps: {
      options: [
        { label: '未评分', value: '0' },
        { label: '已评分', value: '1' },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'checkObject',
    label: '查询对象',
    component: 'Select',
    componentProps: {
      options: [
        { label: '全部', value: '0' },
        { label: '被评对象', value: '1' },
        { label: '参评人', value: '2' },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    label: '姓名',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
];

//问卷/评价结果详情查看表格字段
export const questionnaireDetailTableColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'index',
    width: 60,
    customCell: (record) => {
      return { rowSpan: record.rowSpan };
    },
  },
  {
    title: '标题',
    dataIndex: 'topic',
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpan };
    },
  },
  {
    title: '题目',
    dataIndex: 'problem',
    align: 'left',
  },
  {
    title: '题目分数',
    width: 120,
    dataIndex: 'score',
    align: 'left',
  },
  {
    title: '实际分数',
    dataIndex: 'actualScore',
    align: 'left',
    width: 100,
  },
  {
    title: '意见',
    dataIndex: 'opinion',
    align: 'left',
    width: 200,
  },
];
//评价结果详情搜索字段
export const evaluateResultSearchFormSchema: FormSchema[] = [
  {
    field: 'grade',
    label: '年级',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'baseData/grade/option' },
    },
    colProps: { span: 8 },
  },
  // {
  //   label: '学期',
  //   field: 'semesterId',
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: () => {
  //     return {
  //       api: requestMagicApi,
  //       getPopupContainer: () => document.body,
  //       params: {
  //         url: '/baseData/semester/option',
  //       },
  //       showSearch: true,
  //       filterOption: (input: string, option: any) => {
  //         return (
  //           option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
  //           option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
  //         );
  //       },
  //     };
  //   },
  // },
  {
    field: 'classId',
    label: '班级',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'educational/class/option' },
    },
    colProps: { span: 8 },
  },
  {
    field: 'teacher',
    label: '任课教师',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      getPopupContainer: () => document.body,
      params: { url: 'educational/abutment/teacher-info' },
      fieldNames: { label: 'name', value: 'id' },
    },
    colProps: { span: 8 },
  },
  {
    label: '姓名',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
];
//评价结果表格字段
export const evaluateResultTableColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'index',
    width: 60,
    customCell: (record) => {
      return { rowSpan: record.rowSpanTopic };
    },
  },
  {
    title: '被评对象',
    dataIndex: 'objectIdCN',
    width: 120,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanTopic };
    },
  },
  {
    title: '应打分人数',
    dataIndex: 'planExecuterNum',
    width: 80,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanTopic };
    },
  },
  {
    title: '实际打分人数',
    dataIndex: 'actualExecuterNum',
    width: 80,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanTopic };
    },
  },
  {
    title: '题目',
    align: 'left',
    dataIndex: 'problem',
  },
  {
    title: '得分',
    width: 80,
    align: 'left',
    dataIndex: 'sumScore',
  },
  {
    title: '标题',
    dataIndex: 'topic',
    width: 200,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanProblem };
    },
  },
  {
    title: '得分',
    dataIndex: 'topicScore',
    width: 80,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanProblem };
    },
  },
  {
    title: '综合评分',
    dataIndex: 'synthesisScore',
    width: 80,
    align: 'left',
    customCell: (record) => {
      return { rowSpan: record.rowSpanTopic };
    },
  },
];
