import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { getBasestudentassessmentprojectTree } from '/@/services/apis/BaseStudentAssessmentProjectController';
export const type = {
  0: '菜单',
  1: '目录',
};

export const status = {
  1: '是',
  0: '否',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '考核项',
    dataIndex: 'name',
  },
  {
    title: '编号',
    dataIndex: 'code',
  },
  {
    title: '考核类型',
    dataIndex: 'scoreType',
  },
  {
    title: '分值',
    dataIndex: 'score',
  },
  {
    title: '是否允许调整',
    dataIndex: 'isAdjustment',
    customRender: ({ text }) => {
      return status[text];
    },
  },
  {
    title: '可调分值范围',
    dataIndex: 'scoreRange',
    customRender: ({ record }) => {
      return `${record.pointsDeductedMin}-${record.pointsDeductedMax}`;
    },
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    label: 'id',
    field: 'id',
    show: false,
    component: 'Input',
  },
  {
    label: '考核项',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '考核项编号',
    field: 'code',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '考核类型',
    field: 'scoreType',
    component: 'RadioGroup',
    componentProps: {
      options: [...(await getDataOption({ code: 'score_type' }))],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '分值',
    field: 'score',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '是否允许调整',
    field: 'isAdjustment',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        {
          label: '是',
          value: 1,
        },
        {
          label: '否',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '换算为班级考核项目加/扣分采用',
    field: 'automaticScoreType',
    component: 'RadioGroup',
    ifShow: ({ values }) => {
      return values.isAdjustment === 1;
    },
    componentProps: {
      options: [...(await getDataOption({ code: 'score_type' }))],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '是否允许修改',
    field: 'isEdit',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '是',
          value: 1,
        },
        {
          label: '否',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '最大可调分值',
    field: 'pointsDeductedMax',
    component: 'InputNumber',
    required: true,

    colProps: { span: 24 },

    ifShow: ({ values }) => {
      return values.isAdjustment === 1;
    },
  },

  {
    label: '最小可调分值',
    field: 'pointsDeductedMin',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },

    ifShow: ({ values }) => {
      return values.isAdjustment === 1;
    },
  },
  {
    label: '影响班级考核',
    field: 'isImpactAssessment',
    component: 'RadioGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        {
          label: '是',
          value: 1,
        },
        {
          label: '否',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '对应班级考核项',
    field: 'baseStudentAssessmentProjectId',
    component: 'ApiTreeSelect',
    ifShow: ({ values }) => {
      return values.isAdjustment === 1;
    },
    componentProps: {
      getPopupContainer: () => document.body,
      treeDefaultExpandAll: true,
      api: async () => {
        const data = await getBasestudentassessmentprojectTree({});
        data.forEach((item: any) => {
          //   如果有子节点，就不允许选择
          if (item.children && item.children.length > 0) {
            item.disabled = true;
            item.label = item.name;
            item.value = item.id;
            item.children.forEach((child: any) => {
              child.label = child.name;
              child.value = child.id;
            });
          } else {
            item.label = item.name;
            item.value = item.id;
          }
        });
        return data;
      },
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '状态',
    field: 'status',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '使用中',
          value: 1,
        },
        {
          label: '已停用',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
];

export const typeSchema: FormSchema[] = [
  {
    label: '编码',
    field: 'code',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '备注',
    field: 'remark',
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    label: '是否启用',
    field: 'status',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        {
          label: '启用',
          value: 1,
        },
        {
          label: '停用',
          value: 0,
        },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },

  ]
