import { requestMagicApi } from '/@/api/magicApi';
import { BasicColumn, FormSchema } from '/@/components/Table';
export const assessmentTypeOptions = [
  { label: '个人', value: 'personal' },
  { label: '班级', value: 'class' },
];

export const tableColumns: BasicColumn[] = [
  {
    title: '学号',
    dataIndex: 'Studentcode',
    align: 'left',
  },
  {
    title: '姓名',
    dataIndex: 'feeobjname',
    width: 100,
    align: 'left',
  },
  {
    title: '性别',
    dataIndex: 'sex',
    width: 60,
    align: 'left',
  },
  {
    title: '学期',
    dataIndex: 'semesterName',
    width: 120,
    align: 'left',
  },
  {
    title: '项目',
    dataIndex: 'feeitemname',
    width: 100,
    align: 'left',
  },
  {
    title: '应收',
    dataIndex: 'standardar',
    width: 100,
    align: 'left',
  },
  {
    title: '调整金额',
    dataIndex: 'adjustmny',
    width: 100,
    align: 'left',
  },
  {
    title: '调整后应收',
    dataIndex: 'factar',
    width: 100,
    align: 'left',
  },
  {
    title: '实收',
    dataIndex: 'factrecarmny',
    width: 100,
    align: 'left',
  },
  {
    title: '退费金额',
    dataIndex: 'refundmny',
    width: 100,
    align: 'left',
  },
  {
    title: '欠费金额',
    dataIndex: 'qfje',
    width: 100,
    align: 'left',
  },
  {
    title: '状态',
    dataIndex: 'jfzt',
    width: 150,
    align: 'left',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'semesterId',
    label: '学期',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/semester/option' },
    },
    colProps: { span: 8 },
  },
  {
    field: 'feeitemname',
    label: '项目',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '影响', value: '1' },
        { label: '不影响', value: '0' },
      ],
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'category',
    label: '类型',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        { label: '退费', value: '-1' },
        { label: '缴费', value: '1' },
      ],
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'studentId',
    label: '学号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    label: '时间',
    field: '[startDate,endDate]',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: { format: 'HH:mm' },
      placeholder: ['开始时间', '结束时间'],
    },
    colProps: { span: 8 },
  },
  {
    field: 'payorder',
    label: '订单号',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '考核细则',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '分数',
    field: 'basicPoints',
    component: 'InputNumber',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '考核对象',
    field: 'assessmentType',
    component: 'Select',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      options: assessmentTypeOptions,
    },
  },
  {
    label: '响学生操行分',
    field: 'isAffect',
    component: 'RadioButtonGroup',
    defaultValue: 0,
    componentProps: {
      options: [
        { label: '不影响', value: 0 },
        { label: '影响', value: 1 },
      ],
      numberToString: true,
    },
    colProps: { span: 24 },
  },
];
