import { BasicColumn, FormSchema } from '/@/components/Table';
import { getBasestudentcadreClasslist } from '/@/services/apis/BaseStudentCadreController';
import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
export const type = {
  0: '菜单',
  1: '目录',
};

export const status = {
  1: '在职',
  0: '离职',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '获奖名称',
    dataIndex: 'name',
  },
  {
    title: '获奖日期',
    dataIndex: 'awardDate',
  },
  {
    title: '荣誉等级',
    dataIndex: 'honorsGradeCN',
  },
  {
    title: '荣誉级别',
    dataIndex: 'honorsLevelCN',
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'name',
    label: '荣誉名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'baseSemesterId',
    label: '获奖学期',
    component: 'ApiSelect',
    colProps: { span: 24 },
    required: true,
    componentProps: () => {
      return {
        api: requestMagicApi,
        params: {
          url: '/baseData/semester/option',
        },
      };
    },
  },
  {
    field: 'classId',
    label: '所属班级',
    component: 'ApiSelect',
    componentProps: () => {
      return {
        api: requestMagicApi,
        params: {
          url: '/educational/class/option',
        },
      };
    },
    colProps: { span: 24 },
    required: true,
  },
  {
    field: 'awardDate',
    label: '获奖日期',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
      showTime: false,
    },
    colProps: { span: 24 },
  },
  {
    field: 'honorsGrade',
    label: '荣誉等级',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_grade` },
    },
    required: true,
  },
  {
    field: 'honorsLevel',
    label: '荣誉级别',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_level` },
    },
    required: true,
  },
  {
    field: 'fileId',
    label: '附件',
    component: 'Upload',
    slot: 'upload',
    colProps: { span: 24 },
  },
];

export const studentTableColumns: BasicColumn[] = [
  {
    title: '学生姓名',
    dataIndex: 'name',
  },
  {
    title: '学生学号',
    dataIndex: 'userName',
  },
  {
    title: '任职开始时间',
    dataIndex: 'startTime',
    slots: { customRender: 'startTime' },
  },
  {
    title: '任职结束时间',
    dataIndex: 'endTime',
    slots: { customRender: 'endTime' },
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    label: '班级列表',
    field: 'classId',
    component: 'ApiSelect',
    defaultValue: '',
    colProps: { span: 8 },
    componentProps: ({ formModel }) => {
      return {
        api: async () => {
          const data = await getBasestudentcadreClasslist({});
          formModel.classId = data[0].id;
          return data;
        },
        showSearch: true,
        treeNodeFilterProp: 'name',
        labelField: 'name',
        // use id as value
        valueField: 'id',
      };
    },
  },
  {
    field: 'honorsGrade',
    label: '荣誉等级',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_grade` },
    },
  },
  {
    field: 'honorsType',
    label: '荣誉类型',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_type` },
    },
  },
];
