import { BasicColumn, FormSchema } from '/@/components/Table';
import { getBasestudentcadreClasslist } from '/@/services/apis/BaseStudentCadreController';
import { requestMagicApi } from '/@/api/magicApi';
import { getDataOption } from '/@/api/system/dic';
import { log } from 'console';
export const type = {
  0: '菜单',
  1: '目录',
};

export const status = {
  1: '在职',
  0: '离职',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '学生学号',
    dataIndex: 'studentId',
  },
  {
    title: '学生姓名',
    dataIndex: 'studentName',
  },
  {
    title: '奖项名称',
    dataIndex: 'name',
  },
  {
    title: '荣誉级别',
    dataIndex: 'honorsLevel',
  },
  {
    title: '荣誉类型',
    dataIndex: 'honorsType',
  },
  {
    title: '荣誉等级',
    dataIndex: 'honorsGrade',
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'baseSemesterId',
    label: '获奖学期',
    component: 'ApiSelect',
    colProps: { span: 24 },
    required: true,
    componentProps: () => {
      return {
        api: requestMagicApi,
        params: {
          url: '/baseData/semester/option',
        },
      };
    },
  },
  {
    field: 'classId',
    label: '所属班级',
    component: 'ApiSelect',
    componentProps: () => {
      return {
        api: requestMagicApi,
        params: {
          url: '/educational/class/option',
        },
      };
    },
    colProps: { span: 24 },
    required: true,
  },
  {
    field: 'studentUserId',
    label: '申请学生',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: ({ formModel }) => {
      return {
        api: requestMagicApi,
        params: {
          url: `/student/class/list?class_id=${formModel.classId}`,
        },
        showSearch: true,
        //  搜索的属性值
        optionFilterProp: 'name',
        fieldNames: { label: 'name', value: 'userId' },
        onChange: async (e) => {
          const data = await requestMagicApi({
            url: `/student/student/detailInfo?user_id=${e}`,
          });

          formModel.majorSetId = data[0].majorSetId;
          formModel.studentId = data[0].studentId;
        },
      };
    },
    required: true,
  },
  {
    field: 'studentId',
    label: '学号',
    component: 'Input',
    colProps: { span: 24 },
    dynamicDisabled: true,
    required: true,
  },
  {
    field: 'majorSetId',
    label: '所学专业',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: requestMagicApi,
      params: { url: `/major/majorset/option` },
    },
    dynamicDisabled: true,
    required: true,
  },
  {
    field: 'name',
    label: '奖项名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'awardDate',
    label: '获奖日期',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
      showTime: false,
    },
    colProps: { span: 24 },
  },
  {
    field: 'honorsGrade',
    label: '荣誉等级',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_grade` },
    },
    required: true,
  },
  {
    field: 'honorsType',
    label: '荣誉类型',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_type` },
    },
    required: true,
  },
  {
    field: 'honorsLevel',
    label: '荣誉级别',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_level` },
    },
    required: true,
  },
  {
    field: 'fileId',
    label: '附件',
    component: 'Upload',
    slot: 'upload',
    colProps: { span: 24 },
  },
];

export const studentTableColumns: BasicColumn[] = [
  {
    title: '学生姓名',
    dataIndex: 'name',
  },
  {
    title: '学生学号',
    dataIndex: 'userName',
  },
  {
    title: '任职开始时间',
    dataIndex: 'startTime',
    slots: { customRender: 'startTime' },
  },
  {
    title: '任职结束时间',
    dataIndex: 'endTime',
    slots: { customRender: 'endTime' },
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    label: '班级列表',
    field: 'classId',
    component: 'ApiSelect',
    defaultValue: '',
    componentProps: ({ formModel }) => {
      return {
        // 挂载在body
        getPopupContainer: () => document.body,
        api: async () => {
          const data = await getBasestudentcadreClasslist({});
          formModel.classId = data[0].id;
          return data;
        },
        showSearch: true,
        treeNodeFilterProp: 'name',
        labelField: 'name',
        // use id as value
        valueField: 'id',
      };
    },
  },
  {
    field: 'honorsGrade',
    label: '荣誉等级',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_grade` },
    },
    required: true,
  },
  {
    field: 'honorsType',
    label: '荣誉类型',
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getDataOption,
      params: { code: `honors_type` },
    },
    required: true,
  },
];
