import { BasicColumn, FormSchema } from '/@/components/Table';
import { VNode, h } from 'vue';
import { getAppEnvConfig } from '/@/utils/env';
import { encode } from 'js-base64';
import { getDepartmentTree } from '/@/api/system/department';

export const tableColumns: BasicColumn[] = [
  {
    title: '编号',
    dataIndex: 'number',
    align: 'left',
    width: 150,
  },
  {
    title: '名称',
    dataIndex: 'flowName',
    align: 'left',
    width: 150,
  },
  {
    title: '申请人',
    dataIndex: 'userName',
    align: 'left',
    width: 100,
  },
  {
    title: '申购部门',
    dataIndex: 'orgName',
    align: 'left',
    width: 150,
  },
  {
    title: '申购时间',
    dataIndex: 'shenQingRiQi4752',
    width: 150,
  },
  {
    title: '预估总额',
    dataIndex: 'totalAmount',
    align: 'left',
    width: 80,
  },
  {
    title: '附件',
    dataIndex: 'fileInfos',
    align: 'left',
    customRender: ({ text }) => {
      const ha: VNode[] = [];
      text.forEach((item) => {
        ha.push(
          h(
            'a',
            {
              href:
                getAppEnvConfig().VITE_GLOB_FFFILEVIEW_URL +
                encodeURIComponent(encode(item.fileUrl)),
              target: '_blank',
            },
            item.fileName,
          ),
        );
      });
      return h('div', null, ha);
    },
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    label: '申购部门',
    field: 'orgId',
    component: 'ApiTreeSelect',
    colProps: { span: 8 },
    componentProps: () => {
      return {
        getPopupContainer: () => document.body,
        api: getDepartmentTree,
        fieldNames: {
          label: 'name',
          key: 'id',
          value: 'id',
        },
        treeNodeFilterProp: 'name',
        treeDefaultExpandAll: true,
        showSearch: true,
      };
    },
  },
  {
    field: '[startDate,endDate]',
    label: '申购时间',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD',
      placeholder: ['开始时间', '结束时间'],
      // showTime: true,
    },
    colProps: { span: 10 },
  },
  {
    field: 'userName',
    label: '申请人',
    component: 'Input',
    colProps: { span: 6 },
  },
];
