import { requestMagicApi } from '/@/api/magicApi';
import { BasicColumn, FormSchema } from '/@/components/Table';

export const tableColumns: BasicColumn[] = [
  {
    title: '台账名称',
    dataIndex: 'ledgerName',
    align: 'left',
    width: 150,
  },
  {
    title: '菜单名称',
    dataIndex: 'menuName',
    align: 'left',
    width: 120,
  },
  {
    title: '说明',
    dataIndex: 'remark',
    align: 'left',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '关键字',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '菜单编号',
    field: 'code',
    component: 'Input',
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '菜单名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 12 },
  },
  {
    label: '上级菜单',
    field: 'parentId',
    component: 'MenuSelect',
    required: true,
    colProps: { span: 12 },
    componentProps: {
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'ledgerConfigId',
    label: '台账选择',
    required: true,
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: 'educational/ledgerConfig/option' },
      getPopupContainer: () => document.body,
      showSearch: true,
      filterOption: (input: string, option: any) => {
        return (
          option.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    colProps: { span: 12 },
  },
  {
    field: 'sortCode',
    label: '排序',
    required: true,
    component: 'InputNumber',
    colProps: { span: 12 },
  },
  {
    field: 'icon',
    label: '图标',
    required: true,
    component: 'IconPicker',
    colProps: { span: 12 },
  },
  {
    field: 'remark',
    label: '备注',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
];
