import { FormSchema } from '/@/components/Form';

import { BasicColumn } from '/@/components/Table';
import { getMaterialtypeList } from '/@/services/apis/MaterialTypeController';
import { h } from 'vue';
import { Tinymce } from '/@/components/Tinymce';
export const TableColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '指派人',
    dataIndex: 'createUserName',
    align: 'left',
    width: 120,
  },
  {
    title: '要求完成日期',
    dataIndex: 'requiredCompleteTime',
    align: 'left',
    width: 150,
  },
  {
    title: '任务状态',
    dataIndex: 'status',
    customRender: ({ text }) => {
      return text === 1 ? '未开始' : text === 2 ? '进行中' : text === 3 ? '结束' : '';
    },
    align: 'left',
    width: 80,
  },
  {
    title: '执行状态',
    dataIndex: 'processStatus',
    align: 'left',
    width: 80,
    customRender: ({ text }) => {
      return text === 1
        ? '未提交'
        : text === 2
        ? '待审核'
        : text === 3
        ? '通过'
        : text === 4
        ? '重做'
        : '';
    },
  },

  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 100,
  },
];
export const RulesColumns: BasicColumn[] = [
  {
    title: '学号工号',
    dataIndex: 'userName',
  },
  {
    title: '身份',
    dataIndex: 'userType',
    customRender: ({ text }) => {
      return text === 1 ? '教职工' : text === 2 ? '学生' : '';
    },
  },
  {
    title: '状态',
    dataIndex: 'executiveStatus',
    customRender: ({ text }) => {
      return text === 1 ? '未提交' : text === 2 ? '已提交' : '延迟提交';
    },
  },

  {
    title: '本次是否发送消息',
    dataIndex: 'sendMessage',
    customRender: ({ text }) => {
      return text === 1 ? '发送' : '不发送';
    },
  },
];

export const SearchSchema: FormSchema[] = [
  {
    field: 'type',
    label: '任务类型',
    component: 'ApiSelect',
    componentProps: {
      api: getMaterialtypeList,
      labelField: 'name',
      valueField: 'id',
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    label: '任务名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'status',
    label: '任务状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '进行中', value: 2 },
        { label: '结束', value: 3 },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'extStatus',
    label: '执行状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '未提交', value: 1 },
        { label: '待审核', value: 2 },
        { label: '通过', value: 3 },
      ],
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    label: '指派人',
    field: 'assignedUser',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'name',
    label: '任务名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'status',
    label: '任务状态',
    component: 'RadioButtonGroup',
    componentProps: {
      options: [
        { label: '未开始', value: 1 },
        { label: '进行中', value: 2 },
      ],
    },
    defaultValue: 1,
    required: true,
  },
  {
    field: 'materialTypeId',
    label: '任务类型',
    component: 'ApiSelect',
    componentProps: {
      api: getMaterialtypeList,
      labelField: 'name',
      valueField: 'id',
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'requiredCompleteTime',
    label: '要求完成日期',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'requirement',
    label: '要求',
    component: 'Input',
    colProps: { span: 24 },
    render: ({ model, field }) => {
      return h(Tinymce, {
        value: model[field],
        onChange: (value: string) => {
          model[field] = value;
        },
      });
    },
    required: true,
  },
  {
    field: 'materialTaskAppendixList',
    label: '附件',
    component: 'Upload',
    slot: 'Upload',
  },
];
