import { FormSchema } from '/@/components/Form';

import { BasicColumn } from '/@/components/Table';
import { getMaterialtypeList } from '/@/services/apis/MaterialTypeController';
import { h } from 'vue';
import { Tinymce } from '/@/components/Tinymce';
export const TableColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '任务类型',
    dataIndex: 'materialTypeIdCn',
    align: 'left',
    width: 120,
  },
  {
    title: '发布时间',
    dataIndex: 'createDate',
    align: 'left',
    width: 120,
  },
  {
    title: '要求完成日期',
    dataIndex: 'requiredCompleteTime',
    align: 'left',
    width: 120,
  },
  {
    title: '指派人数',
    dataIndex: 'assignPerson',
    align: 'left',
    width: 80,
  },
  {
    title: '已提交',
    dataIndex: 'submitedPerson',
    align: 'left',
    width: 80,
  },
  {
    title: '未提交',
    dataIndex: 'unSubmitPerson',
    customRender: ({ record }) => {
      return record.assignPerson - record.submitedPerson;
    },
    align: 'left',
    width: 80,
  },
  {
    title: '按时提交',
    dataIndex: 'onTimePerson',
    align: 'left',
    width: 80,
  },
  {
    title: '延迟提交',
    dataIndex: 'timeDelay',
    align: 'left',
    width: 80,
  },
  {
    title: '任务状态',
    dataIndex: 'status',
    customRender: ({ text }) => {
      return text === 1 ? '未开始' : text === 2 ? '进行中' : text === 3 ? '结束' : '';
    },
    align: 'left',
    width: 100,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];
export const RulesColumns: BasicColumn[] = [
  {
    title: '学号工号',
    dataIndex: 'userName',
  },
  {
    title: '身份',
    dataIndex: 'userType',
    customRender: ({ text }) => {
      return text === 1 ? '教职工' : text === 2 ? '学生' : '';
    },
  },
  {
    title: '状态',
    dataIndex: 'executiveStatus',
    customRender: ({ text }) => {
      return text === 1 ? '未提交' : text === 2 ? '已提交' : '延迟提交';
    },
  },

  {
    title: '本次是否发送消息',
    dataIndex: 'sendMessage',
    customRender: ({ text }) => {
      return text === 1 ? '发送' : '不发送';
    },
  },
];
export const TodoList: BasicColumn[] = [
  { title: '姓名', dataIndex: 'name' },
  {
    title: '学号工号',
    dataIndex: 'userNumber',
  },
  {
    title: '身份',
    dataIndex: 'userType',
    customRender: ({ text }) => {
      return text === 1 ? '教职工' : text === 2 ? '学生' : '';
    },
  },
  {
    title: '部门',
    dataIndex: 'deptName',
  },
  {
    title: '状态',
    dataIndex: 'status',
    customRender: ({ text }) => {
      /** 状态 1=未提交 2=待审核 3=通过 4=重做 */
      return text === 1
        ? '未提交'
        : text === 2
        ? '待审核'
        : text === 3
        ? '通过'
        : text === 4
        ? '重做'
        : '';
    },
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
  },
];

export const SearchSchema: FormSchema[] = [
  {
    label: '任务名称',
    field: 'name',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'materialTypeId',
    label: '任务类型',
    component: 'ApiSelect',
    componentProps: {
      api: getMaterialtypeList,
      labelField: 'name',
      valueField: 'id',
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
  {
    field: 'status',
    label: '任务状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '未开始', value: 1 },
        { label: '进行中', value: 2 },
        { label: '结束', value: 3 },
      ],
    },
    colProps: { span: 8 },
  },
  {
    field: '[createDateStart,createDateEnd]',
    label: '发布日期',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      placeholder: ['开始时间', '结束时间'],
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: { format: 'HH:mm:ss' },
    },
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'name',
    label: '任务名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'materialTypeId',
    label: '任务类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'materialCategory',
    label: '模板类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'materialCategoryName',
    label: ' ',
    component: 'Input',
    colProps: { span: 24 },
    slot: 'materialCategoryName',
  },
  {
    field: 'requiredCompleteTime',
    label: '要求完成日期',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      valueFormat: 'YYYY-MM-DD',
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'requirement',
    label: '要求',
    component: 'Input',
    colProps: { span: 24 },
    render: ({ model, field }) => {
      return h(Tinymce, {
        value: model[field],
        onChange: (value: string) => {
          model[field] = value;
        },
      });
    },
    required: true,
  },
  {
    field: 'sendMessage',
    label: '发送消息',
    component: 'RadioButtonGroup',
    colProps: { span: 24 },
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ],
    },
  },
  // {
  //   field: 'materialTaskAppendixList',
  //   label: '附件',
  //   component: 'Upload',
  //   required: true,
  //   slot: 'Upload',
  // },
];

export const ViewSearchSchema: FormSchema[] = [
  // {
  //   label: '身份',
  //   field: 'userType',
  //   component: 'Select',
  //   componentProps: {
  //     options: [
  //       { label: '教职工', value: 1 },
  //       { label: '学生', value: 2 },
  //     ],
  //   },
  //   colProps: { span: 8 },
  // },
  {
    label: '姓名',
    field: 'userName',
    component: 'Input',
    colProps: { span: 8 },
  },
  // {
  //   label: '机构/行政班',
  //   field: 'deptName',
  //   component: 'Input',
  //   colProps: { span: 8 },
  // },
];

export const auditSchema: FormSchema[] = [
  {
    label: '审核结果',
    field: 'status',
    component: 'RadioGroup',
    required: true,
    defaultValue: 1,
    componentProps: {
      options: [
        { label: '通过', value: 1 },
        { label: '重做', value: 2 },
      ],
    },
    colProps: { span: 24 },
  },
  {
    label: '是否延迟提交',
    field: 'executiveStatus',
    component: 'RadioGroup',
    defaultValue: 1,
    required: true,
    ifShow: (form) => {
      return form.model.status === 1;
    },
    colProps: { span: 24 },

    componentProps: {
      options: [
        { label: '按时提交', value: 1 },
        { label: '延迟提交', value: 2 },
      ],
    },
  },
  {
    label: '审核意见',
    field: 'opinion',
    component: 'InputTextArea',
    colProps: { span: 24 },

    required: (form) => {
      return form.model.status === 2;
    },
  },
];
