import { BasicColumn, FormSchema } from '/@/components/Table';
import { getDataOption } from '/@/api/system/dic';
import { FormTypeEnum } from '/@/enums/formtypeEnum';
import { getFormTemplateList } from '/@/api/form/design';

export const tableColumns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    align: 'left',
    width: 150,
  },
  {
    title: '模板类型',
    dataIndex: 'materialCategoryCn',
    align: 'left',
    width: 200,
  },
  {
    title: '模板预览',
    dataIndex: 'templatePreview',
    align: 'left',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'materialCategory',
    label: '模板类型',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: () => {
        return getDataOption({ code: 'material_category' });
      },
      getPopupContainer: () => document.body,
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '名称',
    field: 'name',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'materialCategory',
    label: '模板类型',
    component: 'ApiSelect',
    required: true,
    colProps: { span: 24 },
    componentProps: {
      api: () => {
        return getDataOption({ code: 'material_category' });
      },
      getPopupContainer: () => document.body,
      mode: 'multiple',
    },
  },
  {
    label: '附件',
    field: 'folderId',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    ifShow: ({ values }) => values.materialCategory?.indexOf('MT0001') > -1,
    slot: 'folderId',
  },
  {
    label: '表单',
    field: 'formReleaseId',
    component: 'ApiSelect',
    required: true,
    colProps: { span: 24 },
    ifShow: ({ values }) => values.materialCategory?.indexOf('MT0002') > -1,
    componentProps: {
      api: getFormTemplateList,
      labelField: 'name',
      valueField: 'id',
      getPopupContainer: () => document.body,
      params: {
        type: FormTypeEnum.CUSTOM_FORM,
      },
      showSearch: true,
    },
  },
];
