import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { h } from 'vue';
import { Tinymce } from '/@/components/Tinymce';

export const sexOptions = [
  {
    label: '男',
    value: 1,
  },
  {
    label: '女',
    value: 0,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'authorName',
    label: '作者名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'fullHead',
    label: '新闻标题',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'keyword',
    label: '关键字',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'sendStartDate',
    label: '张贴时间',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      getPopupContainer: () => document.body,
    },
    colProps: { span: 8 },
  },
];

export const columns: BasicColumn[] = [
  {
    dataIndex: 'authorName',
    title: '作者',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'briefHead',
    title: '简略标题',
    sorter: true,
  },

  {
    dataIndex: 'releaseTime',
    title: '发布时间',

    sorter: true,
  },

  {
    dataIndex: 'sourceAddress',
    title: '来源地址',
    componentType: 'input',
  },
];

export const baseFromSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'fullHead',
    label: '完整标题',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'briefHead',
    label: '简略标题',
    component: 'Input',
    required: true,
    colProps: { span: 11 },
  },
  {
    field: 'fullHeadColor',
    label: '标题颜色',
    component: 'ColorPicker',
    defaultValue: '#000000',
    colProps: { span: 11 },
  },
  {
    field: 'emergent',
    label: '紧急程度',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '一般',
          value: 1,
        },
        {
          label: '紧急',
          value: 2,
        },
      ],
    },
    required: true,
    colProps: { span: 11 },
  },
  {
    field: 'authorName',
    label: '发布人',
    component: 'Input',
    required: true,
    colProps: { span: 11 },
  },
  {
    field: 'compileName',
    label: '编辑',
    component: 'Input',
    required: true,

    colProps: { span: 11 },
  },
  {
    field: 'keyword',
    label: '关键字',
    component: 'Input',
    colProps: { span: 11 },
  },
  {
    field: 'releaseTime',
    label: '发布时间',
    component: 'DatePicker',
    required: true,

    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 11 },
  },
  {
    field: 'sendStartDate',
    label: '张贴开始时间',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 11 },
  },
  {
    field: 'sendEndDate',
    label: '张贴结束时间',
    required: true,

    component: 'DatePicker',
    helpComponentProps: {
      text: '不填结束时间则代表无限制',
    },
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 11 },
  },
  {
    field: 'sourceAddress',
    label: '来源地址',
    component: 'Input',
    colProps: { span: 11 },
  },
  {
    field: 'tagWord',
    label: '标签',
    component: 'Input',
    colProps: { span: 11 },
  },
  {
    field: 'remark',
    label: '概要',
    component: 'InputTextArea',
    required: true,
    componentProps: {
      rows: 4,
    },
    colProps: { span: 24 },
  },
  {
    field: 'newsContent',
    component: 'Input',
    label: '新闻内容',
    rules: [{ required: true }],
    colProps: { span: 24 },
    render: ({ model, field }) => {
      return h(Tinymce, {
        value: model[field],
        onChange: (value: string) => {
          model[field] = value;
        },
      });
    },
  },
];
