import { FormSchema } from '/@/components/Form';
import { BasicColumn } from '/@/components/Table';
import { h } from 'vue';
import { Tinymce } from '/@/components/Tinymce';
import { getDepartmentEnabledTree } from '/@/services/apis/DepartmentController';
export const sexOptions = [
  {
    label: '男',
    value: 1,
  },
  {
    label: '女',
    value: 0,
  },
];
// export const searchFormSchema: FormSchema[] = [
//   {
//     field: 'userName',
//     label: '工号',
//     component: 'Input',
//     colProps: { span: 8 },
//   },
//   {
//     field: 'mobile',
//     label: '手机号',
//     component: 'Input',
//     colProps: { span: 8 },
//   },
//   {
//     field: 'name',
//     label: '姓名',
//     component: 'Input',
//     colProps: { span: 8 },
//   },
//   {
//     field: 'email',
//     label: '邮箱',
//     component: 'Input',
//     colProps: { span: 8 },
//   },
// ];

export const columns: BasicColumn[] = [
  {
    dataIndex: 'authorName',
    title: '作者',
    componentType: 'input',

    sorter: true,
  },

  {
    dataIndex: 'briefHead',
    title: '简略标题',
    sorter: true,
  },

  {
    dataIndex: 'releaseTime',
    title: '发布时间',

    sorter: true,
  },

  {
    dataIndex: 'sourceAddress',
    title: '来源地址',
    componentType: 'input',
  },
];

export const baseFromSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'id',
    component: 'Input',
    show: false,
  },
  {
    field: 'fullHead',
    label: '公告标题',
    component: 'Input',
    required: true,
    colProps: { span: 12 },
  },
  {
    field: 'fullHeadColor',
    label: '标题颜色',
    component: 'ColorPicker',
    defaultValue: '#000000',
    colProps: { span: 12 },
  },
  {
    field: 'sendDeptId',
    label: '发文部门',
    component: 'ApiTreeSelect',
    required: true,
    componentProps: {
      treeDefaultExpandAll: true,
      api: getDepartmentEnabledTree,
      getPopupContainer: () => document.body,
      replaceFields: {
        label: 'name',
        value: 'id',
      },
    },
    colProps: { span: 12 },
  },
  {
    field: 'releaseTime',
    label: '发布时间',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
    },
    required: true,

    colProps: { span: 12 },
  },
  {
    field: 'emergent',
    label: '紧急程度',
    component: 'RadioGroup',
    required: true,
    componentProps: {
      options: [
        {
          label: '一般',
          value: 1,
        },
        {
          label: '紧急',
          value: 2,
        },
      ],
    },
  },
  {
    field: 'openReply',
    label: '接收人回复',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '必须回复', value: 1 },
        { label: '不允许回复', value: 2 },
        { label: '可以回复', value: 3 },
      ],
    },
    required: true,
    colProps: { span: 12 },
  },
  {
    field: 'sendRange',
    label: '发送范围',
    component: 'RadioGroup',
    defaultValue: 1,
    componentProps: {
      options: [
        { label: '全体教职工', value: 1 },
        { label: '权限师生', value: 2 },
        { label: '指定人员', value: 3 },
      ],
    },
    required: true,
    colProps: { span: 12 },
  },

  {
    field: 'sendEndDate',
    label: '张贴结束时间',
    component: 'DatePicker',
    helpMessage: '不填写则代表无限制',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 12 },
  },
  {
    field: 'selectUser',
    label: '指定人员',
    component: 'Input',
    slot: 'selectUser',
    ifShow: ({ model }) => {
      return model.sendRange === 3;
    },
    colProps: { span: 24 },
  },
  {
    field: 'newsContent',
    component: 'Input',
    label: '公告内容',
    rules: [{ required: true }],
    colProps: { span: 24 },
    componentProps: {
      maxLength: 1000,
      showWordLimit: true,
    },
    render: ({ model, field }) => {
      return h(Tinymce, {
        value: model[field],
        onChange: (value: string) => {
          model[field] = value;
        },
      });
    },
  },
  {
    field: 'appendixList',
    label: '附件',
    component: 'Upload',
    componentProps: {},
    slot: 'Upload',
    colProps: { span: 24 },
  },
  {
    field: 'status',
    label: '状态',
    component: 'Input',
    defaultValue: 1,
    show: false,
  },
];

export const UserColumns: BasicColumn[] = [
  {
    dataIndex: 'userName',
    title: '账号',
  },
  {
    dataIndex: 'name',
    title: '姓名',
  },
  {},
];

export const relationColumns: BasicColumn[] = [
  {
    dataIndex: 'relationName',
    title: '名称',
  },
  {
    dataIndex: 'relationType',
    title: '类型',
    customRender: ({ record }) => {
      return record.relationType === 1 ? '部门' : record.relationType === 2 ? '人员' : '班级';
    },
  },
];

export const searchFormSchema2: FormSchema[] = [
  {
    field: 'departmentId',
    label: '所属部门',
    component: 'ApiTreeSelect',
    componentProps: {
      treeDefaultExpandAll: true,
      api: getDepartmentEnabledTree,
      getPopupContainer: () => document.body,
      replaceFields: {
        label: 'name',
        value: 'id',
      },
    },
    colProps: { span: 12 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    colProps: { span: 12 },
  },
];
