import { BasicColumn, FormSchema } from '/@/components/Table';
import { BasicOptionModel } from '/@/api/model/baseModel';
export const statusOptions: BasicOptionModel[] = [
  {
    label: '进',
    value: 1,
  },
  {
    label: '出',
    value: 2,
  },
];

export const passingOptions: BasicOptionModel[] = [
  {
    label: '识别过车',
    value: 0,
  },
  {
    label: '人工处置',
    value: 1,
  },
];
export const baseColumns: BasicColumn[] = [
  {
    title: '车牌号',
    dataIndex: 'carNo',
    width: 100,
    align: 'center',
  },
  {
    title: '进场时间',
    dataIndex: 'inTime',
    width: 150,
  },
  {
    title: '出场时间',
    dataIndex: 'outTime',
  },
  {
    title: '状态',
    dataIndex: 'status',
    customRender: ({ record }) => {
      return statusOptions.find((item) => item.value === record.status)?.label;
    },
  },
  {
    title: '进类型',
    dataIndex: 'inPassing',
    customRender: ({ record }) => {
      return passingOptions.find((item) => item.value === record.inPassing)?.label;
    },
  },
  {
    title: '出类型',
    dataIndex: 'outPassing',
    customRender: ({ record }) => {
      return passingOptions.find((item) => item.value === record.outPassing)?.label;
    },
  },

  {
    title: '备注',
    dataIndex: 'remark',
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'carNo',
    label: '车牌号',
    component: 'Input',
    colProps: { span: 8 },
  },
  // {
  //   field: 'cSyncStatus',
  //   label: '数据同步状态',
  //   component: 'Select',
  //   componentProps: {
  //     //渲染到body
  //     getPopupContainer: () => document.body,
  //     options: [
  //       { label: '未同步', value: 1 },
  //       { label: '已同步', value: 2 },
  //       { label: '同步失败', value: 3 },
  //     ],
  //   },
  // },
  {
    field: 'startInTime',
    label: '进场区间',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      showTime: true,
    },
  },
  {
    field: 'endInTime',
    label: '进场结束时间',
    component: 'Input',
    show: false,
  },
  {
    field: 'startOutTime',
    label: '出场区间',
    component: 'RangePicker',
    componentProps: {
      getPopupContainer: () => document.body,
      showTime: true,
    },
  },
  {
    field: 'endOutTime',
    label: '出场结束时间',
    component: 'Input',
    show: false,
  },
  {
    field: 'inPassing',
    label: '进类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: passingOptions,
    },
  },
  {
    field: 'outPassing',
    label: '出',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: passingOptions,
    },
  },
];
