import { BasicColumn, FormSchema } from '/@/components/Table';
import { BasicOptionModel } from '/@/api/model/baseModel';
export const cTypeOptions: BasicOptionModel[] = [
  {
    label: '民用',
    value: 1,
  },
  {
    label: '军队',
    value: 2,
  },
  {
    label: '警用',
    value: 3,
  },
  {
    label: '武警',
    value: 4,
  },
];

export const cFeeTypeOptions: BasicOptionModel[] = [
  {
    label: '月租',
    value: 1,
  },
  {
    label: '临时',
    value: 2,
  },
  {
    label: '免费',
    value: 3,
  },
  {
    label: '储值',
    value: 4,
  },
];
export const baseColumns: BasicColumn[] = [
  {
    title: '车牌号',
    dataIndex: 'carNo',
    width: 100,
    align: 'center',
  },
  {
    title: '姓名',
    dataIndex: 'cName',
    width: 100,
  },
  {
    title: '联系电话',
    dataIndex: 'cPhone',
  },
  {
    title: '车辆类型',
    dataIndex: 'cType',
    //     渲染
    customRender: ({ record }) => {
      return cTypeOptions.find((item) => item.value === record.cType)?.label;
    },
  },
  {
    title: '收费类型',
    dataIndex: 'cFeeType',
    customRender: ({ record }) => {
      return cFeeTypeOptions.find((item) => item.value === record.cFeeType)?.label;
    },
  },
  {
    title: '数据同步状态',
    dataIndex: 'cSyncStatus',
    customRender: ({ record }) => {
      switch (record.cSyncStatus) {
        case 1:
          return '未同步';
        case 2:
          return '已同步';
        case 3:
          return '同步失败';
      }
    },
  },
  {
    title: '数据同步编号',
    dataIndex: 'cSyncId',
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'carNo',
    label: '车牌号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'cName',
    label: '姓名',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'cSyncStatus',
    label: '数据同步状态',
    component: 'Select',
    componentProps: {
      //渲染到body
      getPopupContainer: () => document.body,
      options: [
        { label: '未同步', value: '1' },
        { label: '已同步', value: '2' },
        { label: '同步失败', value: '3' },
      ],
    },
  },
  {
    field: 'cType',
    label: '车辆类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: cTypeOptions,
    },
  },
  {
    field: 'cFeeType',
    label: '收费类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: cFeeTypeOptions,
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'userId',
    label: '用户ID',
    component: 'Input',
    required: true,
    slot: 'userId',
    colProps: { span: 24 },
  },
  {
    field: 'carNo',
    label: '车牌号',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'cName',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'cId',
    label: '身份证号',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    rules: [
      {
        pattern: /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/,
        message: '身份证号格式错误',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'cAddress',
    label: '联系地址',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },

  {
    field: 'cPhone',
    label: '联系电话',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    rules: [
      {
        pattern: /^1[3456789]\d{9}$/,
        message: '手机号格式错误',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'cType',
    label: '车辆类型',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: cTypeOptions,
    },
    required: true,
  },
  {
    field: 'cFeeType',
    label: '收费类型',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: cFeeTypeOptions,
    },
    required: true,
  },
  {
    field: 'cStartTime',
    label: '开始时间',
    component: 'DatePicker',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    required: true,
  },
  {
    field: 'cEndTime',
    label: '结束时间',
    component: 'DatePicker',
    required: true,
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
    },
  },
];
