import { BasicColumn, FormSchema } from '/@/components/Table';
import { BasicOptionModel } from '/@/api/model/baseModel';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
export const statusOptions: BasicOptionModel[] = [
  {
    label: '出口',
    value: 0,
  },
  {
    label: '入口',
    value: 1,
  },
];
export const resultStatusOption: BasicOptionModel[] = [
  {
    label: '成功',
    value: 1,
  },
  {
    label: '失败',
    value: 0,
  },
];

export const passingOptions: BasicOptionModel[] = [
  {
    label: '识别过车',
    value: 0,
  },
  {
    label: '人工处置',
    value: 1,
  },
];
export const baseColumns: BasicColumn[] = [
  {
    title: '设备唯一标识',
    dataIndex: 'macAddr',
    width: 150,
    align: 'center',
  },
  {
    title: '人脸图片',
    dataIndex: 'faceBase64',
    align: 'center',
    customRender: ({ record }) => {
      //   render img渲染
      return h('img', {
        src: record.faceBase64,
        style: { width: '100px', height: '100px', margin: '0 auto', objectFit: 'contain' },
      });
    },
  },
  {
    title: '人脸编号',
    dataIndex: 'faceCode',
    width: 150,
  },

  {
    title: '比对结果',
    dataIndex: 'resultStatus',
    width: 150,
    customRender: ({ record }) => {
      switch (record.resultStatus) {
        case 1:
          return h(Tag, { color: 'success' }, () => `成功`);
        case 0:
          return h(Tag, { color: 'error' }, () => `失败`);
      }
    },
  },
  {
    title: '比对时间',
    dataIndex: 'verifyTime',
  },
  {
    title: '设备名称',
    dataIndex: 'deviceName',
  },

  {
    title: '出/入口',
    dataIndex: 'inoutDirection',
    customRender: ({ record }) => {
      return statusOptions.find((item) => item.value === record.inoutDirection)?.label;
    },
  },
  {
    title: '姓名',
    dataIndex: 'name',
  },
  // {
  //   title: '体温',
  //   dataIndex: 'temperature',
  //   customRender: ({ record }) => {
  //     return record.temperature + '℃';
  //   },
  // },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'devicename',
    label: '设备名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'name',
    label: '人员名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'location',
    label: '安装位置',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'inout',
    label: '进/出口',
    component: 'Select',
    componentProps: {
      //渲染到body
      getPopupContainer: () => document.body,
      options: statusOptions,
    },
    colProps: { span: 8 },
  },

  {
    field: 'startTime',
    label: '比对区间',
    component: 'RangePicker',
    componentProps: {
      showTime: true,
    },
    colProps: { span: 8 },
  },
  {
    field: 'endTime',
    label: '比对结束时间',
    component: 'Input',
    show: false,
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'userId',
    label: '用户ID',
    component: 'Input',
    required: true,
    slot: 'userId',
    colProps: { span: 24 },
  },
  {
    field: 'carNo',
    label: '车牌号',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'cName',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'cId',
    label: '身份证号',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    rules: [
      {
        pattern: /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/,
        message: '身份证号格式错误',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'cAddress',
    label: '联系地址',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },

  {
    field: 'cPhone',
    label: '联系电话',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    rules: [
      {
        pattern: /^1[3456789]\d{9}$/,
        message: '手机号格式错误',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'cType',
    label: '车辆类型',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: statusOptions,
    },
    required: true,
  },
  {
    field: 'cFeeType',
    label: '收费类型',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      options: passingOptions,
    },
    required: true,
  },
  {
    field: 'cStartTime',
    label: '开始时间',
    component: 'DatePicker',
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
    },
    required: true,
  },
  {
    field: 'cEndTime',
    label: '结束时间',
    component: 'DatePicker',
    required: true,
    colProps: { span: 24 },
    componentProps: {
      getPopupContainer: () => document.body,
      format: 'YYYY-MM-DD HH:mm:ss',
    },
  },
];
