import { BasicColumn, FormSchema } from '/@/components/Table';
import { BasicOptionModel } from '/@/api/model/baseModel';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
export const cTypeOptions: BasicOptionModel[] = [
  {
    label: '民用',
    value: 1,
  },
  {
    label: '军队',
    value: 2,
  },
  {
    label: '警用',
    value: 3,
  },
  {
    label: '武警',
    value: 4,
  },
];

export const cFeeTypeOptions: BasicOptionModel[] = [
  {
    label: '月租',
    value: 1,
  },
  {
    label: '临时',
    value: 2,
  },
  {
    label: '免费',
    value: 3,
  },
  {
    label: '储值',
    value: 4,
  },
];
export const baseColumns: BasicColumn[] = [
  {
    title: '人脸编号',
    dataIndex: 'faceCode',
    width: 100,
    align: 'center',
  },
  {
    title: '人脸照片',
    dataIndex: 'face',
    width: 200,
    align: 'center',
    slots: { customRender: 'face' },
  },
  {
    title: '姓名',
    dataIndex: 'name',
    width: 100,
  },
  {
    title: '性别',
    dataIndex: 'sex',
    customRender: ({ record }) => {
      switch (record.sex) {
        case '1':
          return '男';
        case '0':
          return '女';
        case '-1':
          return '未知';
      }
    },
  },
  {
    title: '身份证号',
    dataIndex: 'idno',
    //     渲染
  },
  {
    title: '开始时间',
    dataIndex: 'peopleStartDate',
  },
  {
    title: '结束时间',
    dataIndex: 'peopleEndDate',
  },
  {
    title: '验证状态',
    dataIndex: 'verifyStatus',
    customRender: ({ record }) => {
      switch (record.verifyStatus) {
        case 1:
          return h(Tag, { color: 'warning' }, () => `未验证`);
        case 2:
          return h(Tag, { color: 'success' }, () => `通过`);
        case 3:
          return h(Tag, { color: 'error' }, () => `失败`);
      }
    },
  },
  {
    title: '同步状态',
    dataIndex: 'syncStatus',
    customRender: ({ record }) => {
      switch (record.verifyStatus) {
        case 1:
          return h(Tag, { color: 'warning' }, () => `未同步`);
        case 2:
          return h(Tag, { color: 'success' }, () => `已同步`);
        case 3:
          return h(Tag, { color: 'error' }, () => `同步失败`);
      }
    },
  },
  {
    title: '状态',
    dataIndex: 'status',
    customRender: ({ record }) => {
      switch (record.status) {
        case 1:
          return h(Tag, { color: 'success' }, () => `启用`);
        case 2:
          return h(Tag, { color: 'pink' }, () => `禁用`);
      }
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'faceCode',
    label: '人脸编号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
  },
  {
    field: 'cSyncStatus',
    label: '数据同步状态',
    component: 'Select',
    componentProps: {
      //渲染到body
      getPopupContainer: () => document.body,
      options: [
        { label: '未同步', value: '1' },
        { label: '已同步', value: '2' },
        { label: '同步失败', value: '3' },
      ],
    },
  },
  {
    field: 'cType',
    label: '车辆类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: cTypeOptions,
    },
  },
  {
    field: 'cFeeType',
    label: '收费类型',
    component: 'Select',
    componentProps: {
      getPopupContainer: () => document.body,
      options: cFeeTypeOptions,
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'userId',
    label: '用户ID',
    component: 'Input',
    required: true,
    slot: 'userId',
    colProps: { span: 24 },
  },
  {
    field: 'faceCode',
    label: '人脸编号',
    component: 'Input',
    rules: [
      {
        //十位数字的正则表达式
        pattern: /^[0-9]{10}$/,
        message: '人脸编号必须为10位数字',
        trigger: 'blur',
      },
    ],
    slot: 'faceCode',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'sex',
    label: '性别',
    component: 'Select',
    componentProps: {
      //渲染到body
      getPopupContainer: () => document.body,
      options: [
        { label: '男', value: '1' },
        { label: '女', value: '0' },
        { label: '保密', value: '-1' },
      ],
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'idno',
    label: '身份证号',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
    rules: [
      {
        pattern: /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/,
        message: '身份证号格式错误',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'peopleStartDate',
    label: '名单有效期开始时间',
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 24 },
  },
  {
    field: 'peopleEndDate',
    label: '名单结束开始时间',
    component: 'DatePicker',
    required: true,
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
    },
    colProps: { span: 24 },
  },
  {
    field: 'file',
    label: '人脸照片',
    component: 'Upload',
    slot: 'registerBase64',
    required: true,
    colProps: { span: 24 },
  },

  {
    field: 'status',
    label: '状态',
    component: 'Switch',
    componentProps: {
      checkedChildren: '启用',
      unCheckedChildren: '禁用',
    },
    colProps: { span: 24 },
  },
];
