import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';

interface dataListItem {
  name: string;
  value: string | number;
  type: 'proportion' | 'numeric';
  status: 'up' | 'down' | null;
}

export type DataList = dataListItem[];

export const TableColumns: BasicColumn[] = [
  {
    title: '流程名称',
    dataIndex: 'processName',
    align: 'left',
  },
  {
    title: '发起人',
    dataIndex: 'originator',
    width: 150,
  },
  {
    title: '发起时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '当前进度',
    dataIndex: 'currentProgress',
    width: 120,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];
export const CirculationColumns: BasicColumn[] = [
  {
    title: '流程名称',
    dataIndex: 'processName',
    align: 'left',
  },
  {
    title: '发起人',
    dataIndex: 'originator',
    width: 150,
  },
  {
    title: '发起时间',
    dataIndex: 'createTime',
    align: 'left',
    width: 150,
  },
  {
    title: '当前进度',
    dataIndex: 'currentProgress',
    width: 120,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];

export const todoList: BasicColumn[] = [
  {
    title: '流程名称',
    dataIndex: 'processName',
    align: 'left',
  },
  {
    title: '发起人',
    dataIndex: 'startUserName',
    align: 'center',
    width: 150,
  },
  {
    title: '流转时间',
    dataIndex: 'startTime',
    width: 150,
  },
  {
    title: '当前进度',
    dataIndex: 'currentProgress',
    width: 150,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];
export const workFlowList: BasicColumn[] = [
  {
    title: '流程名称',
    dataIndex: 'name',
    align: 'left',
  },
  {
    title: '流程分类',
    dataIndex: 'categoryName',
    align: 'center',
    width: 150,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];

export const ExamineColumns: BasicColumn[] = [
  {
    title: '流程名称',
    dataIndex: 'processName',
    align: 'left',
  },
  {
    title: '发起人',
    dataIndex: 'startUserName',
    width: 150,
  },
  {
    title: '发起时间',
    dataIndex: 'launchTime',
    align: 'left',
    width: 150,
  },
  {
    title: '当前进度',
    dataIndex: 'currentProgress',
    width: 120,
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    align: 'center',
    width: 120,
  },
];

export const ChangePassFormSchema: FormSchema[] = [
  {
    field: 'oldPassword',
    component: 'Input',
    label: '旧密码',
    required: true,
    show: true,
    defaultValue: '',
    colProps: { span: 24 },
  },
  {
    field: 'newPassword',
    component: 'InputPassword',
    label: '新密码',
    required: true,
    show: true,
    defaultValue: '',
    colProps: { span: 24 },
  },
  {
    field: 'confirmPassword',
    component: 'InputPassword',
    label: '确认密码',
    required: true,
    show: true,
    defaultValue: '',
    colProps: { span: 24 },
    dynamicRules: ({ values }) => {
      return [
        {
          required: true,
          message: '确认密码不能为空',
        },
        {
          validator: (_, value) => {
            if (!value || values.newPassword === value) {
              return Promise.resolve();
            }
            return Promise.reject('两次输入的密码不一致!');
          },
        },
      ];
    },
  },
];
