import { BasicColumn, FormSchema } from '/@/components/Table';
import { requestMagicApi } from '/@/api/magicApi';
export const type = {
  0: '菜单',
  1: '目录',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '学科组名称',
    dataIndex: 'groupName',
    width: 120,
  },
  {
    title: '学科组长名称',
    dataIndex: 'leaderUserIdCN',
    width: 120,
  },
  {
    title: '学科组课程',
    dataIndex: 'subjectGroupCourseList',
    customRender: ({ text }) => {
      return text.map((item) => item.courseSubjectIdCN).join(',');
    },
    align: 'left',
  },
  {
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    width: 120,
  },
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    component: 'Input',
    label: 'id',
    show: false,
  },
  {
    label: '学科组名',
    field: 'groupName',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '组长名称',
    field: 'leaderUserId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: '/educational/all-teacher' },
      valueField: 'teacherUserId',
      labelField: 'teacherUserName',
      showSearch: true,
      filterOption: (input, option) => {
        return (
          option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '学科组课程',
    field: 'subjectGroupCourseIds',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        api: requestMagicApi,
        params: { url: '/educational/subject/option-unselected' + `?id=${formModel.id}` },
        showSearch: true,
        mode: 'multiple',
        // 搜索参考
        filterOption: (input, option) => {
          return (
            option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '备注',
    field: 'remark',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '学科组名',
    field: 'groupName',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    label: '组长名称',
    field: 'leaderUserId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: '/educational/all-teacher' },
      valueField: 'teacherUserId',
      labelField: 'teacherUserName',
      showSearch: true,
      filterOption: (input, option) => {
        return (
          option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    colProps: { span: 8 },
  },
];
