import { BasicColumn, FormSchema } from '/@/components/Table';
import { requestMagicApi } from '/@/api/magicApi';
import { getSubjectGroupInfo } from '/@/services/apis/SubjectGroupController';
import { getDataOption } from '/@/api/system/dic';
import { getMajorSetOption } from '/@/api/userMagic';
export const type = {
  0: '菜单',
  1: '目录',
};
export const TableColumns: BasicColumn[] = [
  {
    title: '书号（ISSN）',
    dataIndex: 'issn',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '书名',
    dataIndex: 'bookName',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '出版社',
    dataIndex: 'publishingHouse',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '作者（主编）',
    dataIndex: 'editorInChief',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '学科组',
    dataIndex: 'groupName',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '使用学期',
    dataIndex: 'baseSemesterIdCn',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '使用班级',
    dataIndex: 'useClass',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '对应课程',
    dataIndex: 'courseName',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '类型',
    dataIndex: 'textbookTypeCn',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '入库数量',
    dataIndex: 'warehouseNumber',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '单价',
    dataIndex: 'price',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '折扣',
    dataIndex: 'discount',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '入库人员',
    dataIndex: 'warehouseUser',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '入库时间',
    dataIndex: 'createDate',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
  {
    title: '规则型号',
    dataIndex: 'specificationsModels',
    width: 100,
    align: 'left',
    customRender: ({ text }) => {
      return text ? text : '/';
    },
  },
];
export const Eumns = {
  name: '公文名称',
  remark: '发文说明',
  number: '发文字号',
  orgName: '发文部门',
  institution: '发文单位意见',
  backOpinion: '会办单位意见',
  dateOfIssue: '印发日期',
  urgency: '紧急程度',
  confidentialityPeriod: '保密期限',
  tags: '主题词',
  printNumber: '打印份数',
};
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    component: 'Input',
    label: 'id',
    show: false,
  },
  {
    label: '学科组名',
    field: 'groupName',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '组长名称',
    field: 'leaderUserId',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: '/educational/all-teacher' },
      valueField: 'teacherUserId',
      labelField: 'teacherUserName',
      showSearch: true,
      filterOption: (input, option) => {
        return (
          option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '学科组课程',
    field: 'subjectGroupCourseIds',
    component: 'ApiSelect',
    componentProps: {
      api: requestMagicApi,
      params: { url: '/educational/subject/option-unselected' },
      showSearch: true,
      mode: 'multiple',
      // 搜索参考
      filterOption: (input, option) => {
        return (
          option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
          option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
        );
      },
    },
    required: true,
    colProps: { span: 24 },
  },
  {
    label: '备注',
    field: 'remark',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    label: '教材类型',
    field: 'textbookType',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'textbook_type' },
    },
    colProps: { span: 6 },
  },
  {
    label: '学期',
    field: 'baseSemesterId',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: 'baseData/semester/option' },
    },
    colProps: { span: 6 },
  },
  {
    label: '学科组',
    field: 'subjectGroupId',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: requestMagicApi,
      params: { url: '/educational/subjectGroup/list' },
    },
    colProps: { span: 6 },
  },
  {
    label: '书号',
    field: 'issn',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    label: '书名',
    field: 'bookName',
    component: 'Input',
    colProps: { span: 6 },
  },

  // {
  //   label: '出版社名称',
  //   field: 'publishingHouse',
  //   component: 'Input',
  //   colProps: { span: 6 },
  // },
  // {
  //   field: 'majorSetId',
  //   label: '专业方向',
  //   component: 'ApiSelect',
  //   componentProps: ({}) => {
  //     return {
  //       getPopupContainer: () => document.body,
  //       api: getMajorSetOption,
  //     };
  //   },
  //   colProps: { span: 6 },
  // },
  // {
  //   label: '作者（主编）',
  //   field: 'editorInChief',
  //   component: 'Input',
  //   colProps: { span: 6 },
  // },
  {
    label: '规划教材',
    field: 'isTextbookPlan',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'judgment_method_1' },
    },
    colProps: { span: 6 },
  },

  {
    label: '对应课程',
    field: 'courseSubjectId',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: async () => {
          if (!formModel.subjectGroupId) {
            return [];
          }
          const data = await getSubjectGroupInfo({ id: formModel.subjectGroupId });
          return data.subjectGroupCourseList.map((item) => {
            return {
              label: item.courseSubjectIdCN,
              value: item.courseSubjectId,
            };
          });
        },
        showSearch: true,
        // 搜索参考
        filterOption: (input, option) => {
          return (
            option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '使用班级',
    field: 'classId',
    component: 'ApiSelect',
    componentProps: ({ formModel }) => {
      return {
        getPopupContainer: () => document.body,
        api: requestMagicApi,
        params: { url: `educational/class/option` },
        showSearch: true,
        // mode: 'multiple',
        // 搜索参考
        filterOption: (input, option) => {
          return (
            option?.label.toLowerCase().indexOf(input.toLowerCase()) >= 0 ||
            option?.value.toLowerCase().indexOf(input.toLowerCase()) >= 0
          );
        },
      };
    },
    colProps: { span: 6 },
  },
  {
    label: '作业本类型',
    field: 'textBookType',
    component: 'ApiSelect',
    componentProps: {
      getPopupContainer: () => document.body,
      api: getDataOption,
      params: { code: 'exercise_book_type' },
    },
    colProps: { span: 6 },
  },
  {
    label: '规格型号',
    field: 'specificationsModels',
    component: 'Input',
    colProps: { span: 6 },
  },
  // {
  //   label: '使用年级',
  //   field: 'gradeId',
  //   component: 'ApiSelect',
  //   componentProps: {
  //     getPopupContainer: () => document.body,
  //     api: requestMagicApi,
  //     params: { url: '/baseData/grade/option' },
  //   },
  //   colProps: { span: 6 },
  // },
];
